(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    164029,       3645]
NotebookOptionsPosition[    159806,       3505]
NotebookOutlinePosition[    160239,       3524]
CellTagsIndexPosition[    160196,       3521]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Figures", " ", "for", " ", 
    "\"\<The American Consumer: Reforming, or Just Resting?\>\"", " ", "by", 
    " ", "Christopher", " ", "Carroll", " ", "and", " ", "Jirka", " ", 
    "Slacalek"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Paper", " ", "for", " ", "conference", " ", "on", " ", "the", " ", 
     "outlook", " ", "for", " ", "consumption", " ", "at", " ", "the", " ", 
     "San", " ", "Francisco", " ", "Fed"}], ",", " ", 
    RowBox[{"May", " ", "22", " ", "2009."}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "*)"}]}]], "Input",
 CellChangeTimes->{{3.451866096491877*^9, 3.451866096708351*^9}, {
  3.451877315510754*^9, 3.451877413445777*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], ";", 
  RowBox[{"ParamsAreSet", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "$FrontEnd", "]"}], " ", ">", " ", "0"}], ",", 
     RowBox[{"NBDir", "=", 
      RowBox[{"SetDirectory", "[", 
       RowBox[{"NotebookDirectory", "[", "]"}], "]"}]}]}], "]"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "If", " ", "running", " ", "from", " ", "the", " ", "Notebook", " ", 
    "interface"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "$FrontEnd", "]"}], " ", "\[LessEqual]", " ", 
      "0"}], ",", 
     RowBox[{
     "NBDir", "=", 
      "\"\<~/604/LectureNotes/Consumption/Handouts/ctDiscrete/\
Code/Mathematica/Examples/Copenhagen\>\""}]}], "]"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "If", " ", "running", " ", "from", " ", "the", " ", "Notebook", " ", 
    "interface"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"$VersionNumber", "<", "6"}], ",", 
    RowBox[{"(*", "then", "*)"}], " ", 
    RowBox[{
     RowBox[{
     "Print", "[", 
      "\"\<These programs require Mathematica version 6 or greater.\>\"", 
      "]"}], ";", 
     RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AutoLoadDir", "=", 
   RowBox[{"SetDirectory", "[", "\"\<../../CoreCode/Autoload\>\"", "]"}]}], 
  ";", 
  RowBox[{"Get", "[", "\"\<./init.m\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CoreCodeDir", "=", 
   RowBox[{"SetDirectory", "[", "\"\<..\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", "\"\<./MakeAnalyticalResults.m\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Get", "[", "\"\<./VarsAndFuncs.m\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Method", " ", "of", " ", "creating", " ", "figures", " ", "depends", " ", 
    "on", " ", "whether", " ", "being", " ", "run", " ", "in", " ", "batch", 
    " ", "mode", " ", "or", " ", "interactively"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"$FrontEnd", " ", "\[Equal]", " ", "Null"}], ",", 
     RowBox[{"OpenFigsUsingShell", "=", "True"}], ",", 
     RowBox[{"OpenFigsUsingShell", "=", "False"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", 
   RowBox[{"CoreCodeDir", "<>", "\"\</ParametersBase.m\>\""}], "]"}], ";", 
  RowBox[{"\[GothicG]", "   ", "=", 
   RowBox[{"\[GothicG]Base", "   ", "=", "0.01"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.423301260274438*^9, 3.4233013514880037`*^9}, {
   3.4233013973668137`*^9, 3.4233014120677567`*^9}, {3.423301445646921*^9, 
   3.423301453622164*^9}, 3.4456856857108707`*^9, {3.44568571938316*^9, 
   3.445685719733446*^9}, 3.445685778287335*^9, 3.447956811637019*^9, {
   3.452109577853969*^9, 3.4521095913359613`*^9}, {3.452849546165474*^9, 
   3.452849622010983*^9}, {3.4528496746707172`*^9, 3.452849680105279*^9}, {
   3.5172450333788137`*^9, 3.51724503537192*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "compat"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Combinatorica Graph and Permutations functionality has \
been superseded by preloaded functionaliy. The package now being loaded may \
conflict with this. Please see the Compatibility Guide for details.\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.517245043477663*^9, 3.5172455205487556`*^9, 
  3.517284126977206*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Get", "[", "\"\<./ParametersBase.m\>\"", "]"}], ";", 
   RowBox[{"\[GothicG]", "   ", "=", 
    RowBox[{"\[GothicG]Base", "   ", "=", "0.01"}]}], ";", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[ScriptC]EBase", ",", "\[ScriptM]EBase"}], "}"}], " ", "=", 
    " ", 
    RowBox[{"{", 
     RowBox[{"\[ScriptC]E", ",", "\[ScriptM]E"}], "}"}]}], ";"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Restore", " ", "the", " ", "baseline", " ", "parameter", " ", "values", 
    " ", "and", " ", "solve", " ", "again"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
    "r", " ", ",", "\[CurlyTheta]", " ", ",", "\[GothicG]", ",", "\[Mho]"}], 
    "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "rBase", ",", "\[CurlyTheta]Base", ",", "\[GothicG]Base", ",", 
     "\[Mho]Base"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[ScriptM]Max", "=", 
   RowBox[{"1.5", " ", "\[ScriptM]E"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[ScriptM]MaxMax", "=", 
   RowBox[{"5", " ", "\[ScriptM]E"}]}], ";"}], "\n", 
 RowBox[{"FindStableArm", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Kappa]EBase", " ", "=", " ", 
    RowBox[{"\[Kappa]E", " ", "//", "N"}]}], ";", 
   RowBox[{"\[ScriptC]EBase", " ", "=", " ", 
    RowBox[{"\[ScriptC]E", " ", "//", "N"}]}], ";", 
   RowBox[{"\[ScriptM]EOrig", "=", 
    RowBox[{"\[ScriptM]EBase", " ", "//", "N"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cFuncPlotBasePoints", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"cE", "[", "#", "]"}]}], "}"}], "}"}], "&"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"\[ScriptM]", ",", 
       RowBox[{"{", 
        RowBox[{
        "\[ScriptM]", ",", "0", ",", "\[ScriptM]MaxMax", ",", "0.01"}], 
        "}"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cFuncPlotBase", "=", 
   RowBox[{"cFuncPlot", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"cE", "[", "\[ScriptM]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[ScriptM]", ",", "0", ",", "\[ScriptM]MaxMax"}], "}"}]}], 
     "]"}]}]}], ";"}], "\n"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.414624078143676*^9, 3.414624091349381*^9}, {
   3.4146259149591913`*^9, 3.414625934562437*^9}, {3.414625989724938*^9, 
   3.414626008357986*^9}, {3.423299480225054*^9, 3.423299520306975*^9}, {
   3.423299969975024*^9, 3.423299978756555*^9}, 3.445685700054737*^9, 
   3.445685805742318*^9, {3.447956858258624*^9, 3.4479568764984627`*^9}, {
   3.451809913836842*^9, 3.4518099143748417`*^9}, 3.451877158933157*^9, {
   3.4521093230917253`*^9, 3.452109338262761*^9}, {3.452109528176052*^9, 
   3.4521095312852793`*^9}, 3.45211007692205*^9, {3.452110401886648*^9, 
   3.4521104029560947`*^9}, {3.452111105618905*^9, 3.452111106609457*^9}, 
   3.452201045643758*^9}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Solving ...\"\>"], "Print",
 CellChangeTimes->{
  3.423301458219103*^9, {3.445685782387354*^9, 3.445685808489026*^9}, 
   3.447956815352333*^9, {3.4479568589461718`*^9, 3.447956877661337*^9}, 
   3.4518092243375673`*^9, 3.4518098115631113`*^9, 3.451809889589822*^9, {
   3.4518099198789577`*^9, 3.45180992726381*^9}, 3.451810112677717*^9, 
   3.4518545230412903`*^9, 3.451854569356029*^9, 3.451855910502717*^9, 
   3.4518663824832478`*^9, 3.451877422670114*^9, 3.451877539693719*^9, 
   3.451877915287262*^9, 3.451878514900207*^9, 3.4518787204789886`*^9, {
   3.451914339278337*^9, 3.4519143672314787`*^9}, 3.451921403692363*^9, 
   3.4519294460683727`*^9, 3.451929499349021*^9, 3.45193012669309*^9, 
   3.4521077012205343`*^9, 3.452107757472723*^9, {3.45210793303821*^9, 
   3.4521079399167843`*^9}, 3.4521079980539303`*^9, {3.452109338804068*^9, 
   3.4521093567490263`*^9}, {3.4521095319579973`*^9, 3.452109539842325*^9}, {
   3.45210960141975*^9, 3.4521096300079327`*^9}, 3.4521100804666367`*^9, 
   3.452110297367292*^9, 3.452110360171647*^9, {3.452110405410273*^9, 
   3.452110417348103*^9}, {3.45211049583624*^9, 3.4521105076746473`*^9}, {
   3.452110590724803*^9, 3.45211059550355*^9}, 3.452110634681301*^9, 
   3.452111107722664*^9, 3.452111214387763*^9, 3.452111245919492*^9, 
   3.4521676321179943`*^9, 3.452200972123913*^9, {3.452201020492675*^9, 
   3.452201046818803*^9}, 3.452201451200308*^9, 3.4522475630925217`*^9, 
   3.452247699547331*^9, 3.45284970821307*^9, 3.517245046062049*^9, 
   3.5172455239947767`*^9, 3.5172841298315077`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Below \[ScriptM]MinBound times \[ScriptM]E after \"\>", 
   "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" backwards Euler iterations.\"\>"}],
  SequenceForm[
  "  Below \[ScriptM]MinBound times \[ScriptM]E after ", 88, 
   " backwards Euler iterations."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.423301458219103*^9, {3.445685782387354*^9, 3.445685808489026*^9}, 
   3.447956815352333*^9, {3.4479568589461718`*^9, 3.447956877661337*^9}, 
   3.4518092243375673`*^9, 3.4518098115631113`*^9, 3.451809889589822*^9, {
   3.4518099198789577`*^9, 3.45180992726381*^9}, 3.451810112677717*^9, 
   3.4518545230412903`*^9, 3.451854569356029*^9, 3.451855910502717*^9, 
   3.4518663824832478`*^9, 3.451877422670114*^9, 3.451877539693719*^9, 
   3.451877915287262*^9, 3.451878514900207*^9, 3.4518787204789886`*^9, {
   3.451914339278337*^9, 3.4519143672314787`*^9}, 3.451921403692363*^9, 
   3.4519294460683727`*^9, 3.451929499349021*^9, 3.45193012669309*^9, 
   3.4521077012205343`*^9, 3.452107757472723*^9, {3.45210793303821*^9, 
   3.4521079399167843`*^9}, 3.4521079980539303`*^9, {3.452109338804068*^9, 
   3.4521093567490263`*^9}, {3.4521095319579973`*^9, 3.452109539842325*^9}, {
   3.45210960141975*^9, 3.4521096300079327`*^9}, 3.4521100804666367`*^9, 
   3.452110297367292*^9, 3.452110360171647*^9, {3.452110405410273*^9, 
   3.452110417348103*^9}, {3.45211049583624*^9, 3.4521105076746473`*^9}, {
   3.452110590724803*^9, 3.45211059550355*^9}, 3.452110634681301*^9, 
   3.452111107722664*^9, 3.452111214387763*^9, 3.452111245919492*^9, 
   3.4521676321179943`*^9, 3.452200972123913*^9, {3.452201020492675*^9, 
   3.452201046818803*^9}, 3.452201451200308*^9, 3.4522475630925217`*^9, 
   3.452247699547331*^9, 3.45284970821307*^9, 3.517245046062049*^9, 
   3.5172455239947767`*^9, 3.517284129890079*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Last Point:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.8622275499900367`", ",", "0.3566335600206917`", ",", 
     "0.32707315980472024`", ",", 
     RowBox[{"-", "20.38988112067552`"}], ",", 
     RowBox[{"-", "0.19284824117008242`"}]}], "}"}]}],
  SequenceForm[
  "Last Point:", {0.8622275499900367, 0.3566335600206917, 
   0.32707315980472024`, -20.38988112067552, -0.19284824117008242`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.423301458219103*^9, {3.445685782387354*^9, 3.445685808489026*^9}, 
   3.447956815352333*^9, {3.4479568589461718`*^9, 3.447956877661337*^9}, 
   3.4518092243375673`*^9, 3.4518098115631113`*^9, 3.451809889589822*^9, {
   3.4518099198789577`*^9, 3.45180992726381*^9}, 3.451810112677717*^9, 
   3.4518545230412903`*^9, 3.451854569356029*^9, 3.451855910502717*^9, 
   3.4518663824832478`*^9, 3.451877422670114*^9, 3.451877539693719*^9, 
   3.451877915287262*^9, 3.451878514900207*^9, 3.4518787204789886`*^9, {
   3.451914339278337*^9, 3.4519143672314787`*^9}, 3.451921403692363*^9, 
   3.4519294460683727`*^9, 3.451929499349021*^9, 3.45193012669309*^9, 
   3.4521077012205343`*^9, 3.452107757472723*^9, {3.45210793303821*^9, 
   3.4521079399167843`*^9}, 3.4521079980539303`*^9, {3.452109338804068*^9, 
   3.4521093567490263`*^9}, {3.4521095319579973`*^9, 3.452109539842325*^9}, {
   3.45210960141975*^9, 3.4521096300079327`*^9}, 3.4521100804666367`*^9, 
   3.452110297367292*^9, 3.452110360171647*^9, {3.452110405410273*^9, 
   3.452110417348103*^9}, {3.45211049583624*^9, 3.4521105076746473`*^9}, {
   3.452110590724803*^9, 3.45211059550355*^9}, 3.452110634681301*^9, 
   3.452111107722664*^9, 3.452111214387763*^9, 3.452111245919492*^9, 
   3.4521676321179943`*^9, 3.452200972123913*^9, {3.452201020492675*^9, 
   3.452201046818803*^9}, 3.452201451200308*^9, 3.4522475630925217`*^9, 
   3.452247699547331*^9, 3.45284970821307*^9, 3.517245046062049*^9, 
   3.5172455239947767`*^9, 3.517284129894105*^9}],

Cell[BoxData["\<\"Solving ...\"\>"], "Print",
 CellChangeTimes->{
  3.423301458219103*^9, {3.445685782387354*^9, 3.445685808489026*^9}, 
   3.447956815352333*^9, {3.4479568589461718`*^9, 3.447956877661337*^9}, 
   3.4518092243375673`*^9, 3.4518098115631113`*^9, 3.451809889589822*^9, {
   3.4518099198789577`*^9, 3.45180992726381*^9}, 3.451810112677717*^9, 
   3.4518545230412903`*^9, 3.451854569356029*^9, 3.451855910502717*^9, 
   3.4518663824832478`*^9, 3.451877422670114*^9, 3.451877539693719*^9, 
   3.451877915287262*^9, 3.451878514900207*^9, 3.4518787204789886`*^9, {
   3.451914339278337*^9, 3.4519143672314787`*^9}, 3.451921403692363*^9, 
   3.4519294460683727`*^9, 3.451929499349021*^9, 3.45193012669309*^9, 
   3.4521077012205343`*^9, 3.452107757472723*^9, {3.45210793303821*^9, 
   3.4521079399167843`*^9}, 3.4521079980539303`*^9, {3.452109338804068*^9, 
   3.4521093567490263`*^9}, {3.4521095319579973`*^9, 3.452109539842325*^9}, {
   3.45210960141975*^9, 3.4521096300079327`*^9}, 3.4521100804666367`*^9, 
   3.452110297367292*^9, 3.452110360171647*^9, {3.452110405410273*^9, 
   3.452110417348103*^9}, {3.45211049583624*^9, 3.4521105076746473`*^9}, {
   3.452110590724803*^9, 3.45211059550355*^9}, 3.452110634681301*^9, 
   3.452111107722664*^9, 3.452111214387763*^9, 3.452111245919492*^9, 
   3.4521676321179943`*^9, 3.452200972123913*^9, {3.452201020492675*^9, 
   3.452201046818803*^9}, 3.452201451200308*^9, 3.4522475630925217`*^9, 
   3.452247699547331*^9, 3.45284970821307*^9, 3.517245046062049*^9, 
   3.5172455239947767`*^9, 3.517284129897901*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Above \[ScriptM]MaxBound times \[ScriptM]E after \"\>", 
   "\[InvisibleSpace]", "164", 
   "\[InvisibleSpace]", "\<\" backwards Euler iterations.\"\>"}],
  SequenceForm[
  "  Above \[ScriptM]MaxBound times \[ScriptM]E after ", 164, 
   " backwards Euler iterations."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.423301458219103*^9, {3.445685782387354*^9, 3.445685808489026*^9}, 
   3.447956815352333*^9, {3.4479568589461718`*^9, 3.447956877661337*^9}, 
   3.4518092243375673`*^9, 3.4518098115631113`*^9, 3.451809889589822*^9, {
   3.4518099198789577`*^9, 3.45180992726381*^9}, 3.451810112677717*^9, 
   3.4518545230412903`*^9, 3.451854569356029*^9, 3.451855910502717*^9, 
   3.4518663824832478`*^9, 3.451877422670114*^9, 3.451877539693719*^9, 
   3.451877915287262*^9, 3.451878514900207*^9, 3.4518787204789886`*^9, {
   3.451914339278337*^9, 3.4519143672314787`*^9}, 3.451921403692363*^9, 
   3.4519294460683727`*^9, 3.451929499349021*^9, 3.45193012669309*^9, 
   3.4521077012205343`*^9, 3.452107757472723*^9, {3.45210793303821*^9, 
   3.4521079399167843`*^9}, 3.4521079980539303`*^9, {3.452109338804068*^9, 
   3.4521093567490263`*^9}, {3.4521095319579973`*^9, 3.452109539842325*^9}, {
   3.45210960141975*^9, 3.4521096300079327`*^9}, 3.4521100804666367`*^9, 
   3.452110297367292*^9, 3.452110360171647*^9, {3.452110405410273*^9, 
   3.452110417348103*^9}, {3.45211049583624*^9, 3.4521105076746473`*^9}, {
   3.452110590724803*^9, 3.45211059550355*^9}, 3.452110634681301*^9, 
   3.452111107722664*^9, 3.452111214387763*^9, 3.452111245919492*^9, 
   3.4521676321179943`*^9, 3.452200972123913*^9, {3.452201020492675*^9, 
   3.452201046818803*^9}, 3.452201451200308*^9, 3.4522475630925217`*^9, 
   3.452247699547331*^9, 3.45284970821307*^9, 3.517245046062049*^9, 
   3.5172455239947767`*^9, 3.517284130008233*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Last Point:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "480.2784843649445`", ",", "31.361723944130745`", ",", 
     "0.061079731196664315`", ",", 
     RowBox[{"-", "0.5247781487272944`"}], ",", 
     RowBox[{"-", "1.4476866731025066`*^-6"}]}], "}"}]}],
  SequenceForm[
  "Last Point:", {480.2784843649445, 31.361723944130745`, 
   0.061079731196664315`, -0.5247781487272944, -1.4476866731025066`*^-6}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.423301458219103*^9, {3.445685782387354*^9, 3.445685808489026*^9}, 
   3.447956815352333*^9, {3.4479568589461718`*^9, 3.447956877661337*^9}, 
   3.4518092243375673`*^9, 3.4518098115631113`*^9, 3.451809889589822*^9, {
   3.4518099198789577`*^9, 3.45180992726381*^9}, 3.451810112677717*^9, 
   3.4518545230412903`*^9, 3.451854569356029*^9, 3.451855910502717*^9, 
   3.4518663824832478`*^9, 3.451877422670114*^9, 3.451877539693719*^9, 
   3.451877915287262*^9, 3.451878514900207*^9, 3.4518787204789886`*^9, {
   3.451914339278337*^9, 3.4519143672314787`*^9}, 3.451921403692363*^9, 
   3.4519294460683727`*^9, 3.451929499349021*^9, 3.45193012669309*^9, 
   3.4521077012205343`*^9, 3.452107757472723*^9, {3.45210793303821*^9, 
   3.4521079399167843`*^9}, 3.4521079980539303`*^9, {3.452109338804068*^9, 
   3.4521093567490263`*^9}, {3.4521095319579973`*^9, 3.452109539842325*^9}, {
   3.45210960141975*^9, 3.4521096300079327`*^9}, 3.4521100804666367`*^9, 
   3.452110297367292*^9, 3.452110360171647*^9, {3.452110405410273*^9, 
   3.452110417348103*^9}, {3.45211049583624*^9, 3.4521105076746473`*^9}, {
   3.452110590724803*^9, 3.45211059550355*^9}, 3.452110634681301*^9, 
   3.452111107722664*^9, 3.452111214387763*^9, 3.452111245919492*^9, 
   3.4521676321179943`*^9, 3.452200972123913*^9, {3.452201020492675*^9, 
   3.452201046818803*^9}, 3.452201451200308*^9, 3.4522475630925217`*^9, 
   3.452247699547331*^9, 3.45284970821307*^9, 3.517245046062049*^9, 
   3.5172455239947767`*^9, 3.517284130010839*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Now", " ", "suppose", " ", "that", " ", "there", " ", "is", " ", "an", 
     " ", "exogenous", " ", "perfectly", " ", "certain", " ", "increase", " ",
      "to", " ", "permanent", " ", "income", " ", "by", " ", "the", " ", 
     "amount", " ", "0.2", " ", "per", " ", "year"}], " ", "-", " ", 
    RowBox[{
    "think", " ", "of", " ", "it", " ", "as", " ", "a", " ", "government", 
     " ", "transfer", " ", "received", " ", "by", " ", "everyone", " ", "in", 
     " ", "the", " ", "population", " ", 
     RowBox[{"(", 
      RowBox[{
      "this", " ", "is", " ", "more", " ", "transparent", " ", "than", " ", 
       "introducing", " ", "unemployment", " ", "insurance"}], " "}]}]}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DebtLimPDV", "=", 
     RowBox[{"0.2", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", "R", ")"}], "-", "\[GothicCapitalG]"}], ")"}]}]}], ";", 
    RowBox[{"Stable\[ScriptM]LocusPlot", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[ScriptM]EDelEqZero", "[", "\[ScriptM]", "]"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"\[ScriptM]", ",", 
         RowBox[{"-", "DebtLimPDV"}], ",", "\[ScriptM]MaxMax"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"Thickness", "[", "0.002", "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SimGeneratePath", "[", 
     RowBox[{
      RowBox[{"\[ScriptM]E", "-", "2"}], ",", "30"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[ScriptM]MinNew", ",", "\[ScriptM]MaxNew"}], "}"}], "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "20"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[ScriptC]MinNew", ",", "\[ScriptC]MaxNew"}], "}"}], "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2.`"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"cFunc", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
     "cFuncPlotBase", ",", "Stable\[ScriptM]LocusPlot", "\[IndentingNewLine]",
       ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\[UpperLeftArrow] Sustainable \[ScriptC]\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.6`", " ", "\[ScriptM]E"}], ",", 
           RowBox[{"0.9`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\[ScriptC](\[ScriptM])\[LongRightArrow]\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.1`", " ", "\[ScriptM]E"}], ",", 
           RowBox[{"0.45`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.002", "]"}], ",", 
         RowBox[{"Dashing", "[", 
          RowBox[{"{", "0.02", "}"}], "]"}], ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\[ScriptM]E", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}]}], "}"}], 
          "]"}]}], "}"}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.002", "]"}], ",", 
         RowBox[{"Dashing", "[", 
          RowBox[{"{", "0.02", "}"}], "]"}], ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "\[ScriptC]E"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}]}], "}"}], 
          "]"}]}], "}"}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\< \[UpperLeftArrow] Target\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\[ScriptC](\[ScriptM])\[LongRightArrow]\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.1`", " ", "\[ScriptM]E"}], ",", 
           RowBox[{"0.45`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}], "]"}]}], "}"}],
        "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\[ScriptM]E", ",", 
            "\"\<\!\(\*SubscriptBox[OverscriptBox[\(\[ScriptM]\), \
\(\[Hacek]\)], \(\\\ \)]\)\>\""}], "}"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\[ScriptC]E", ",", 
            "\"\<\!\(\*OverscriptBox[\(\[ScriptC]\), \(\[Hacek]\)]\)\>\""}], 
           "}"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[ScriptM]MinNew", ",", 
           RowBox[{"\[ScriptM]E", "+", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[ScriptC]MinNew", ",", 
           RowBox[{"\[ScriptC]E", "+", ".2"}]}], "}"}]}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[ScriptM]\>\"", ",", "\"\<\[ScriptC]\>\""}], "}"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.451854626006118*^9, 3.4518546359584723`*^9}, {
   3.45185469244312*^9, 3.4518547221271353`*^9}, {3.451854757437765*^9, 
   3.451854848741126*^9}, {3.451854878762167*^9, 3.4518549986098747`*^9}, {
   3.4518550329628267`*^9, 3.451855121555595*^9}, {3.451855157296308*^9, 
   3.4518552185710373`*^9}, {3.45185567547287*^9, 3.451855731452201*^9}, {
   3.4518557666313467`*^9, 3.451855801527637*^9}, {3.451855872001445*^9, 
   3.451855890353849*^9}, {3.451855931095183*^9, 3.4518559796760473`*^9}, {
   3.4518560371571302`*^9, 3.451856099919896*^9}, {3.4518561563622427`*^9, 
   3.451856292513443*^9}, {3.4518563415927477`*^9, 3.451856426313511*^9}, {
   3.451856460823379*^9, 3.4518564660979843`*^9}, {3.451863918570528*^9, 
   3.4518639287264223`*^9}, {3.451863968853507*^9, 3.451864088277103*^9}, {
   3.4518774578250103`*^9, 3.451877493606083*^9}, 3.451877524920869*^9, {
   3.451877675211043*^9, 3.45187769941019*^9}, {3.4518777671919813`*^9, 
   3.451877833496852*^9}, {3.451877868579973*^9, 3.451877869686886*^9}, {
   3.451913981830658*^9, 3.4519140523381767`*^9}, {3.451914166092828*^9, 
   3.451914203911454*^9}, {3.4519142531359453`*^9, 3.451914284369666*^9}, {
   3.452107905786961*^9, 3.45210791575237*^9}, {3.452201000826364*^9, 
   3.452201001427857*^9}, {3.4522010782758017`*^9, 3.4522010999868298`*^9}, 
   3.452247586566533*^9, 3.4528487944528522`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], Thickness[Medium], LineBox[CompressedData["
1:eJwVknk81AkfgOfwY99CkVtlpuJ9XcU6fvFW36+RY2MdRScronJk3LVIkS2t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      "]]}}, {{}, {}, 
    {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJwVjXdQ02cchxnSsrQCIkoRQ4KyFAfj5xWS7wtUQGbZIoiWpXKcelrBGEsq
Q1TWpZ6IjSKgTAVRxLqQX1HZYlBjCQhiKRCSkP2iCErpH8997rn73D1W8YdC
k7Q0NDQCF/l/P7Y9FC4s0MjrbQW3fCdE4HnBZKD2M43UZmcn5kyKIH9fakcY
ppEJbqzVbUIRUA0tq6pFNJJ2d3+Wm1gEARGnEoL5NLKi0ivKUS6CskmfkdI6
Gll+ZvaryWcR+BnyX9MjaOTVoKSg90vFcCVC9oRVRyX/GHSfPuYiBpttmy/R
t1mR8wd8vw/IE8PKXY2aRi1ryeU7PFcdGRKDdIIz7mq2hkwZnL2kYy+BQpP8
fiFhTjqOLTX0ZEvgn8TwgZtnzcgqt+WBfX0S+BrhMjlfvoLMNTiUob1uGuxF
1frDHUZkQ0GecxVzGlZ493NK6cvIM3uKH5R0TkPCxyxL7nFdsrfmi6OzpRQs
lK9GH5lqk888wo6uPSiFqaRzJbPcuVbNgmT344+l8CC5v+jGenlrTfBbzDSS
wb4pr66Lb/mtWvHOGT17ZcDtcXJ4kj0A7WLpzPN7MpgMu9787JQChOedPhfr
yGEl1euYkeU8dAiSR5Ub5HD+Puib8bTRrphOxrUoOdwp9rDW3KSHOpeUZ7PY
cvByMXZ8rfEdEk1Ve9bUyUHQvie3LcYYbapZ+tSAL4fdQcJYvW9MUWChyP7i
vBzMXXfaP5syQ1aNWD/dRgHU2dl3qZfNUd9s+quMYAWYr9Zn5XisQVctomNb
0hRQ2fubrt5yCrJm7Y/7qVwBCSdMvduTrVCmpszHoEsB9IErbPogFRU/vVZr
rlZAUeJwg8TbGr2I+/PFXksl5I4084y569Cwlaegb7sSuLqZUqWBDaqgzMVy
DishgjL5dUeiLfLwcehklSz+k7V1BM12SNvnIb7cqgR+rMm3VGsHxMxM5xqL
lNCFHs99YG5A3eM3bBuNVCB4s1MSI9mIXmYvc6xwV0FRZOHLAO9NqMFfaP44
UQVxWfQ3DwM2o0YxpdswXwVZTfWMm0u2oOSOXMXteypg7UqhRjduQTPdSRrs
ERWcElCWJKRsRe76R3LL9NTwVHZnVNfKCV2nDvM+Oalh4CTHNaXHCU3Et2oy
Y9Qw9+HAOdtsZ/Ru5GVd4Gk1KFoKoyo2u6D6zCg3vwY10LYUrb0vcEFlC/TC
X/lqSDh5dtye44p874dG62hgSGPwrKPdCdRdMmLQbIPB30TKjgACUQ+rUbIt
BorQYCjEk0AnfPTTzOwwdHF8OH6+BLKbcRll2mOwGH/yxS2cQLlhBXcZGzH8
lVf/1jKVQD8uc9/duRWDoeDcmX+5BGrJutQwRMcwWl8zNlpKINOYW2P5DAzN
me2M4XICpW59vooBGOI2aGF+NYEsPsgzyxCG22zmzx1Ni32Gb1SSF4bI9ft/
qOshkOvszILUF4PDXM6Fqj4CFfIMXcp2YNDgXZNX9BNoopqaEuKHoZb5vor7
N4EuRAa9afLHMN8baVIwRiBVU2XN8SAMvPJfDp6dIJB/3qNhu2AMlWm/d+VM
Eagivt94aNGDKH3sDBmBQo2+nKSHYKBh8eAJJYFqhcZ3pIv+qUvPNR0TSJO0
nbwaiqG31IZz9BOBdl5kWISEYSg/ul1yaI5AjQfDQ7TCMfwHrbRfnA==
      "]]}}, 
   InsetBox["\<\"\[UpperLeftArrow] Sustainable \[ScriptC]\"\>", \
{2.8778612702359685`, 0.9495090596619077}, {1, 0}], 
   InsetBox["\<\"\[ScriptC](\[ScriptM])\[LongRightArrow]\"\>", \
{0.4796435450393281, 0.47475452983095384`}, {-1, 0}], 
   {Thickness[0.002], Dashing[{0.02}], 
    LineBox[{{4.796435450393281, 0}, {4.796435450393281, 
      1.0550100662910085`}}]}, 
   {Thickness[0.002], Dashing[{0.02}], 
    LineBox[{{0, 1.0550100662910085`}, {4.796435450393281, 
      1.0550100662910085`}}]}, 
   InsetBox["\<\" \[UpperLeftArrow] Target\"\>", \
{4.796435450393281, 1.0550100662910085`}, {-1, 1}], 
   InsetBox["\<\"\[ScriptC](\[ScriptM])\[LongRightArrow]\"\>", \
{0.4796435450393281, 0.47475452983095384`}, {-1, 0}], 
   {GrayLevel[0], PointSize[Medium], 
    PointBox[{4.796435450393281, 1.0550100662910085`}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\[ScriptM]\"", TraditionalForm], 
    FormBox["\"\[ScriptC]\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{0, 5.796435450393281}, {0, 1.2550100662910084`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{4.796435450393281, 
      FormBox[
      "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(\[ScriptM]\\), \
\\(\[Hacek]\\)], \\(\\\\ \\)]\\)\"", TraditionalForm]}}, {{
     1.0550100662910085`, 
      FormBox[
      "\"\\!\\(\\*OverscriptBox[\\(\[ScriptC]\\), \\(\[Hacek]\\)]\\)\"", 
       TraditionalForm]}}}]], "Output",
 CellChangeTimes->{{3.4518775346803303`*^9, 3.451877542430463*^9}, 
   3.451877676349327*^9, {3.45187777933676*^9, 3.451877792755588*^9}, {
   3.4518778255015793`*^9, 3.451877834456953*^9}, 3.4518778701787977`*^9, 
   3.4518779173538647`*^9, 3.4518785168009253`*^9, 3.4518787223171463`*^9, {
   3.4519139961435957`*^9, 3.451914019326992*^9}, 3.4519140534927177`*^9, 
   3.4519142047356157`*^9, {3.451914265984078*^9, 3.45191428488174*^9}, {
   3.451914341061328*^9, 3.451914369066152*^9}, 3.451921406208104*^9, 
   3.4519294481506367`*^9, 3.451929501128241*^9, 3.4519301285954247`*^9, 
   3.45210770903057*^9, {3.452107744712119*^9, 3.4521077603518*^9}, {
   3.45210791679463*^9, 3.452107944334958*^9}, 3.4521080008299932`*^9, 
   3.452109358977166*^9, {3.452109535183177*^9, 3.452109544244275*^9}, 
   3.452109606368883*^9, 3.452109637362673*^9, 3.452110084464155*^9, 
   3.452110303625824*^9, 3.452110421527875*^9, 3.452111113172543*^9, {
   3.4521112226889887`*^9, 3.452111250231278*^9}, 3.452167635383355*^9, 
   3.452200973422963*^9, {3.4522010233918*^9, 3.452201049694961*^9}, {
   3.452201090609157*^9, 3.452201100749262*^9}, 3.452201453629157*^9, {
   3.4522475771558847`*^9, 3.452247588459504*^9}, 3.452247704754415*^9, 
   3.4528497108169107`*^9, 3.517245047937147*^9, 3.517245524389654*^9, 
   3.517284132259295*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<cFunc\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.451877530075642*^9, 3.451877531729966*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[ScriptM]\[ScriptC]PathPlot", " ", "=", " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Take", "[", 
       RowBox[{"\[ScriptM]\[ScriptC]Path", ",", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "\[ScriptM]\[ScriptC]Path", "]"}], "-", 
           "1"}], ")"}]}]}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", "Medium", "]"}]}], "}"}]}]}], "]"}]}], ";", 
   RowBox[{"WealthShock", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
     "cFuncPlotBase", ",", "Stable\[ScriptM]LocusPlot", ",", 
      "\[ScriptM]\[ScriptC]PathPlot", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\[UpperLeftArrow] Sustainable \[ScriptC]\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.6`", " ", "\[ScriptM]E"}], ",", 
           RowBox[{"0.9`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\[ScriptC](\[ScriptM])\[LongRightArrow]\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.1`", " ", "\[ScriptM]E"}], ",", 
           RowBox[{"0.45`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\[ScriptM]E", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}]}], "}"}], "]"}],
        "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[ScriptM]E", "-", "2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[ScriptM]E", "-", "2"}], ",", 
            RowBox[{"cE", "[", 
             RowBox[{"\[ScriptM]E", "-", "2"}], "]"}]}], "}"}]}], "}"}], 
        "]"}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Arrow", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\[ScriptM]E", ",", 
            RowBox[{"\[ScriptC]E", "/", "2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[ScriptM]E", "-", "2"}], ",", 
            RowBox[{"\[ScriptC]E", "/", "2"}]}], "}"}]}], "}"}], "]"}], "]"}],
       "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{
        "\"\<\!\(\*SubscriptBox[\(\[ScriptC]\), \(t\)]\) \
\[LongRightArrow]\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[ScriptM]E", "-", "2"}], ",", 
           RowBox[{"cE", "[", 
            RowBox[{"\[ScriptM]E", "-", "2"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{
        "\"\< \[LongLeftArrow] \!\(\*SubscriptBox[\(\[ScriptC]\), \(t + \
1\)]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[ScriptM]E", "-", "2", "+", "0.22"}], ",", 
           RowBox[{"cE", "[", 
            RowBox[{"\[ScriptM]E", "-", "2", "+", "0.22"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<Wealth Shock\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[ScriptM]E", "-", "1"}], ",", 
           RowBox[{"\[ScriptC]E", "/", "2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "]"}], "]"}], "\[IndentingNewLine]",
       ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\< \[UpperLeftArrow] Target\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\[ScriptC](\[ScriptM])\[LongRightArrow]\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.1`", " ", "\[ScriptM]E"}], ",", 
           RowBox[{"0.45`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}], "]"}]}], "}"}],
        "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "\[ScriptM]E", ",", 
             "\"\<\!\(\*SubscriptBox[OverscriptBox[\(\[ScriptM]\), \(\[Hacek]\
\)], \(\\\ \)]\)\>\""}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[ScriptM]E", "-", "2"}], ",", 
             "\"\<\!\(\*SubscriptBox[\(\[ScriptM]\), \(t\)]\)\>\""}], "}"}]}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\[ScriptC]E", ",", 
            "\"\<\!\(\*OverscriptBox[\(\[ScriptC]\), \(\[Hacek]\)]\)\>\""}], 
           "}"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[ScriptM]MinNew", ",", 
           RowBox[{"\[ScriptM]E", "+", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[ScriptC]MinNew", ",", 
           RowBox[{"\[ScriptC]E", "+", ".2"}]}], "}"}]}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\[ScriptM]\>\"", ",", "\"\<\[ScriptC]\>\""}], "}"}]}]}], 
     "]"}]}]}], "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.451914317171873*^9, 3.451914349419468*^9}, {
  3.452107732984667*^9, 3.452107741054316*^9}, {3.452107927575135*^9, 
  3.452107928554797*^9}, {3.452109672440377*^9, 3.452109684743208*^9}, {
  3.452247627180211*^9, 3.452247652148172*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], Thickness[Medium], LineBox[CompressedData["
1:eJwVknk81AkfgOfwY99CkVtlpuJ9XcU6fvFW36+RY2MdRScronJk3LVIkS2t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      "]]}}, {{}, {}, 
    {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJwVjXdQ02cchxnSsrQCIkoRQ4KyFAfj5xWS7wtUQGbZIoiWpXKcelrBGEsq
Q1TWpZ6IjSKgTAVRxLqQX1HZYlBjCQhiKRCSkP2iCErpH8997rn73D1W8YdC
k7Q0NDQCF/l/P7Y9FC4s0MjrbQW3fCdE4HnBZKD2M43UZmcn5kyKIH9fakcY
ppEJbqzVbUIRUA0tq6pFNJJ2d3+Wm1gEARGnEoL5NLKi0ivKUS6CskmfkdI6
Gll+ZvaryWcR+BnyX9MjaOTVoKSg90vFcCVC9oRVRyX/GHSfPuYiBpttmy/R
t1mR8wd8vw/IE8PKXY2aRi1ryeU7PFcdGRKDdIIz7mq2hkwZnL2kYy+BQpP8
fiFhTjqOLTX0ZEvgn8TwgZtnzcgqt+WBfX0S+BrhMjlfvoLMNTiUob1uGuxF
1frDHUZkQ0GecxVzGlZ493NK6cvIM3uKH5R0TkPCxyxL7nFdsrfmi6OzpRQs
lK9GH5lqk888wo6uPSiFqaRzJbPcuVbNgmT344+l8CC5v+jGenlrTfBbzDSS
wb4pr66Lb/mtWvHOGT17ZcDtcXJ4kj0A7WLpzPN7MpgMu9787JQChOedPhfr
yGEl1euYkeU8dAiSR5Ub5HD+Puib8bTRrphOxrUoOdwp9rDW3KSHOpeUZ7PY
cvByMXZ8rfEdEk1Ve9bUyUHQvie3LcYYbapZ+tSAL4fdQcJYvW9MUWChyP7i
vBzMXXfaP5syQ1aNWD/dRgHU2dl3qZfNUd9s+quMYAWYr9Zn5XisQVctomNb
0hRQ2fubrt5yCrJm7Y/7qVwBCSdMvduTrVCmpszHoEsB9IErbPogFRU/vVZr
rlZAUeJwg8TbGr2I+/PFXksl5I4084y569Cwlaegb7sSuLqZUqWBDaqgzMVy
DishgjL5dUeiLfLwcehklSz+k7V1BM12SNvnIb7cqgR+rMm3VGsHxMxM5xqL
lNCFHs99YG5A3eM3bBuNVCB4s1MSI9mIXmYvc6xwV0FRZOHLAO9NqMFfaP44
UQVxWfQ3DwM2o0YxpdswXwVZTfWMm0u2oOSOXMXteypg7UqhRjduQTPdSRrs
ERWcElCWJKRsRe76R3LL9NTwVHZnVNfKCV2nDvM+Oalh4CTHNaXHCU3Et2oy
Y9Qw9+HAOdtsZ/Ru5GVd4Gk1KFoKoyo2u6D6zCg3vwY10LYUrb0vcEFlC/TC
X/lqSDh5dtye44p874dG62hgSGPwrKPdCdRdMmLQbIPB30TKjgACUQ+rUbIt
BorQYCjEk0AnfPTTzOwwdHF8OH6+BLKbcRll2mOwGH/yxS2cQLlhBXcZGzH8
lVf/1jKVQD8uc9/duRWDoeDcmX+5BGrJutQwRMcwWl8zNlpKINOYW2P5DAzN
me2M4XICpW59vooBGOI2aGF+NYEsPsgzyxCG22zmzx1Ni32Gb1SSF4bI9ft/
qOshkOvszILUF4PDXM6Fqj4CFfIMXcp2YNDgXZNX9BNoopqaEuKHoZb5vor7
N4EuRAa9afLHMN8baVIwRiBVU2XN8SAMvPJfDp6dIJB/3qNhu2AMlWm/d+VM
Eagivt94aNGDKH3sDBmBQo2+nKSHYKBh8eAJJYFqhcZ3pIv+qUvPNR0TSJO0
nbwaiqG31IZz9BOBdl5kWISEYSg/ul1yaI5AjQfDQ7TCMfwHrbRfnA==
      "]]}}, {{}, 
    {RGBColor[1, 0, 0], PointSize[Medium], PointBox[CompressedData["
1:eJwBAQL+/SFib1JlAgAAAB8AAAACAAAAbIOmjBlfBkCMELC5lfLoP6YCV/su
XwhAiWeSgYsy6j9a0kBaoRUKQNKcSAxIOes/1KzSpt+PC0BFrJ9HrxTsP0Lc
KGEF2AxAvshoNybO7D8YxpL88fUNQI0u/zBfbO0/HqPwq+/vDkCyXlmLUfTt
Pz4Izcwdyw9AI43Ecclp7j9Ou38z3EUQQPL434vAz+4/FsYAHqWaEEByexhY
lyjvPw7TDINo5RBAycchyDt27z9ANkA6bCcRQKRRnCFEuu8/ZCHSXcdhEUBD
9vk9AvbvP6h3XkhqlRFAx+Cm1UgV8D/jOwTmJMMRQNxL8iFxLPA/K+Rbxavr
EUBkE7Ii4EDwP1YSzTScDxJA5tVsTO1S8D98lGqjfy8SQD9rvuLjYvA/plPZ
bc5LEkDjdcPxBHHwP9gpizXyZBJAwFER5oh98D+sUUvZR3sSQLfKadmgiPA/
XPDPICGPEkDUB46kd5LwP3mUHinGoBJAub54wjKb8D9Q5aecdrASQO4sUw7z
ovA/3RfKv2q+EkC2/09j1anwP5XmuFjUyhJADbz+I/Ov8D+7Onp439USQNk8
eK1itfA/WdefKbPfEkAYGt25N7rwP55klghy6BJARV/ttIO+8D+UPLzIOvAS
QG3J9wRWwvA/+bfsqCj3EkCFtfNJvMXwP/9v9Kw=
      "]]}, {}}, 
   InsetBox["\<\"\[UpperLeftArrow] Sustainable \[ScriptC]\"\>", \
{2.8778612702359685`, 0.9495090596619077}, {1, 0}], 
   InsetBox["\<\"\[ScriptC](\[ScriptM])\[LongRightArrow]\"\>", \
{0.4796435450393281, 0.47475452983095384`}, {-1, 0}], 
   LineBox[{{4.796435450393281, 0}, {4.796435450393281, 
     1.0550100662910085`}}], 
   LineBox[{{2.7964354503932807`, 0}, {2.7964354503932807`, 
     0.7796124102319637}}], 
   ArrowBox[{{4.796435450393281, 0.5275050331455042}, {2.7964354503932807`, 
    0.5275050331455042}}], 
   InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(\[ScriptC]\\), \\(t\\)]\\) \
\[LongRightArrow]\"\>", {2.7964354503932807`, 0.7796124102319637}, {1, 0}], 
   InsetBox["\<\" \[LongLeftArrow] \\!\\(\\*SubscriptBox[\\(\[ScriptC]\\), \
\\(t + 1\\)]\\)\"\>", {3.016435450393281, 0.8140733540500599}, {-1, 0}], 
   InsetBox["\<\"Wealth Shock\"\>", \
{3.7964354503932807`, 0.5275050331455042}, {0, -1}], 
   InsetBox["\<\" \[UpperLeftArrow] Target\"\>", \
{4.796435450393281, 1.0550100662910085`}, {-1, 1}], 
   InsetBox["\<\"\[ScriptC](\[ScriptM])\[LongRightArrow]\"\>", \
{0.4796435450393281, 0.47475452983095384`}, {-1, 0}], 
   {GrayLevel[0], PointSize[Medium], 
    PointBox[{4.796435450393281, 1.0550100662910085`}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\[ScriptM]\"", TraditionalForm], 
    FormBox["\"\[ScriptC]\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{0, 5.796435450393281}, {0, 1.2550100662910084`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{4.796435450393281, 
      FormBox[
      "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(\[ScriptM]\\), \
\\(\[Hacek]\\)], \\(\\\\ \\)]\\)\"", TraditionalForm]}, {
     2.7964354503932807`, 
      FormBox[
      "\"\\!\\(\\*SubscriptBox[\\(\[ScriptM]\\), \\(t\\)]\\)\"", 
       TraditionalForm]}}, {{1.0550100662910085`, 
      FormBox[
      "\"\\!\\(\\*OverscriptBox[\\(\[ScriptC]\\), \\(\[Hacek]\\)]\\)\"", 
       TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.451877551257969*^9, {3.451877908038661*^9, 3.451877919916707*^9}, 
   3.4518785188573914`*^9, 3.451878725617008*^9, {3.451914334126642*^9, 
   3.45191437112778*^9}, 3.451921408366418*^9, 3.4519294503054647`*^9, 
   3.451929502920878*^9, 3.451930130518524*^9, 3.452107762721973*^9, {
   3.452107929366329*^9, 3.45210794842407*^9}, 3.4521080029293957`*^9, 
   3.4521081310148773`*^9, 3.452109361046578*^9, 3.452109610927932*^9, 
   3.452109641674794*^9, 3.452109685504406*^9, 3.4521100875769978`*^9, 
   3.45211031250284*^9, 3.452110427155344*^9, 3.45211111956771*^9, {
   3.45211122509172*^9, 3.452111253374873*^9}, 3.452167642047084*^9, 
   3.452201111510151*^9, 3.4522014561376*^9, {3.452247628320997*^9, 
   3.452247653245187*^9}, 3.4522477099523573`*^9, 3.4528497137613487`*^9, 
   3.517245051767667*^9, 3.517245525925651*^9, 3.517284139771243*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<WealthShock\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.451856310046733*^9, 3.451856312527596*^9}, {
  3.451856501123239*^9, 3.4518565647196217`*^9}, {3.451864904878489*^9, 
  3.451864906118746*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"savRat", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", "r", ")"}], "/", "R"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
          RowBox[{"Table", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"Length", "[", "\[ScriptM]\[ScriptC]Path", "]"}], 
             "}"}]}], "]"}]}], ")"}]}], "-", 
       RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savRat", ",", 
    RowBox[{"savRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savRat", ",", 
    RowBox[{"savRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savRat", ",", 
    RowBox[{"savRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savRat", ",", 
    RowBox[{"savRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timePath", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "savRat", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"savPathPlot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"timePath", ",", "savRat"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Black"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"savPathAfterWealthShock", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"savPathPlot", ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"5", ",", "\"\<t\>\""}], "}"}], "}"}], ",", "None"}], 
      "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", "\"\<\[ScriptS]\>\""}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         RowBox[{"Length", "[", "timePath", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", 
         RowBox[{
          RowBox[{"Max", "[", "savRat", "]"}], "+", "0.01`"}]}], "}"}]}], 
      "}"}]}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.451866126028428*^9, 3.4518661988585043`*^9}, {
  3.4518662393474503`*^9, 3.4518662891032143`*^9}, {3.451866510813486*^9, 
  3.4518665949165497`*^9}, {3.45186668080405*^9, 3.451866859623073*^9}, {
  3.451877979024988*^9, 3.451877999386065*^9}, {3.452109736049985*^9, 
  3.452109769355074*^9}, {3.4521118736457357`*^9, 3.452111877429319*^9}, {
  3.4522011393952723`*^9, 3.452201161839464*^9}, {3.452247665232881*^9, 
  3.4522476787534657`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {GrayLevel[0], PointSize[Medium], PointBox[CompressedData["
1:eJxdyVsogwEYBuC/3WxTRMTG5B9yXMMwhtm7uVPKqbggSw4rQiyt5JSUdqEQ
FwglSuQ0hyYxZyFyYckFf3Gh3Eyu1Bzz/Rf21tfb873yysbCagHDMJE/99t/
cenY25lcWcuCjh74b5GHfT0c4GEJ+mbN0xLzNVmGcXG49tN5SWbBSINUFX3n
5HCMJ9T7Cc9PyZEwXigmgzqOyVGorws9aLYekmPAbc31xD7sk+NQLD8pbGjc
IytwesbtFiU5yEpwrPrQrdkhJ+I5xDSsLt0mJ4EzdMcLbFtkFUwi29et3k5O
hmskY37iY5OcAt8Xr9cSboOcCseipfXtaZ2sxpQ1Rxkm5J2Grtw5n+icNXI6
HFqx7W7YRtZgOdCksbhXyRlgve0RY2bemeB610qU7hVyFvJrWweNA7y1wPb7
5aiKdzaMYleW5X6ZrIMr76Ztd4g3wDxe3ZcVkLuAprF2a3kgv+vhqDnqdx4s
0a4HGyx1DtSQGQO49KrOCf8l3Td2RZwt
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"\[ScriptS]\"", TraditionalForm]},
  AxesOrigin->{-3, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{-3, 36}, {0., 0.2827109524008502}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Ticks->{{{5, 
      FormBox["\"t\"", TraditionalForm]}}, None}]], "Output",
 CellChangeTimes->{
  3.451878003418573*^9, 3.45187852151304*^9, 3.4518787300260878`*^9, 
   3.451914373025298*^9, 3.451921410203561*^9, 3.451929452795191*^9, 
   3.451929505426581*^9, 3.451930132405404*^9, 3.452107766373877*^9, 
   3.4521079534007072`*^9, 3.452108004924798*^9, 3.452108133957602*^9, 
   3.452109364303089*^9, 3.452109707877503*^9, {3.452109751416874*^9, 
   3.452109770768965*^9}, 3.452110091820181*^9, 3.452110321525128*^9, 
   3.4521104315984163`*^9, 3.4521111231900587`*^9, {3.452111227851334*^9, 
   3.4521112577534933`*^9}, {3.4521118790052347`*^9, 3.4521118869997387`*^9}, 
   3.452167645095051*^9, 3.4522011210730963`*^9, {3.452201152563283*^9, 
   3.452201162437416*^9}, 3.452201458107367*^9, 3.452247658083378*^9, 
   3.452247713638658*^9, 3.4528497157745323`*^9, 3.517245055420209*^9, 
   3.517245531062779*^9, 3.517284144556818*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<savPathAfterWealthShock\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{
  3.4518669981886663`*^9, {3.451877591176442*^9, 3.4518775923280277`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Get", "[", "\"\<./ParametersBase.m\>\"", "]"}], ";", 
   RowBox[{"\[GothicG]", "   ", "=", 
    RowBox[{"\[GothicG]Base", "   ", "=", "0.01"}]}], ";", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[ScriptC]EBase", ",", "\[ScriptM]EBase"}], "}"}], " ", "=", 
    " ", 
    RowBox[{"{", 
     RowBox[{"\[ScriptC]E", ",", "\[ScriptM]E"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Restore", " ", "the", " ", "baseline", " ", "parameter", " ", "values", 
    " ", "and", " ", "solve", " ", "again"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
    "r", " ", ",", "\[CurlyTheta]", " ", ",", "\[GothicG]", ",", "\[Mho]"}], 
    "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"rBase", ",", "\[CurlyTheta]Base", ",", "\[GothicG]Base", ",", 
     RowBox[{"3", "\[Mho]Base"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[ScriptM]Max", "=", 
   RowBox[{"1.5", " ", "\[ScriptM]E"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[ScriptM]MaxMax", "=", 
   RowBox[{"7", " ", "\[ScriptM]E"}]}], ";"}], "\n", 
 RowBox[{"FindStableArm", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Kappa]EBase", " ", "=", " ", 
   RowBox[{"\[Kappa]E", " ", "//", "N"}]}], ";", 
  RowBox[{"\[ScriptC]EBase", " ", "=", " ", 
   RowBox[{"\[ScriptC]E", " ", "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cFuncPlotuHigher", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"cE", "[", "\[ScriptM]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[ScriptM]", ",", "0", ",", "\[ScriptM]MaxMax"}], "}"}], ",", 
      
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Thickness", "[", "0.002", "]"}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SimGeneratePath", "[", 
    RowBox[{"\[ScriptM]EOrig", ",", 
     RowBox[{"HowMany", "=", "15"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[ScriptM]\[ScriptC]PathPlot", " ", "=", " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{
      RowBox[{"Take", "[", 
       RowBox[{"\[ScriptM]\[ScriptC]Path", ",", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"HowMany", "+", "1"}], ")"}]}]}], "]"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red"}], "}"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]", "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Get", "[", "\"\<./ParametersBase.m\>\"", "]"}], ";", 
   RowBox[{"\[GothicG]", "   ", "=", 
    RowBox[{"\[GothicG]Base", "   ", "=", "0.01"}]}], ";", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[ScriptC]EBase", ",", "\[ScriptM]EBase"}], "}"}], " ", "=", 
    " ", 
    RowBox[{"{", 
     RowBox[{"\[ScriptC]E", ",", "\[ScriptM]E"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Restore", " ", "the", " ", "baseline", " ", "parameter", " ", "values", 
    " ", "and", " ", "solve", " ", "again"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
    "r", " ", ",", "\[CurlyTheta]", " ", ",", "\[GothicG]", ",", "\[Mho]"}], 
    "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "rBase", ",", "\[CurlyTheta]Base", ",", "\[GothicG]Base", ",", 
     "\[Mho]Base"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[ScriptM]Max", "=", 
   RowBox[{"1.5", " ", "\[ScriptM]E"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[ScriptM]MaxMax", "=", 
   RowBox[{"7", " ", "\[ScriptM]E"}]}], ";"}], "\n", 
 RowBox[{"FindStableArm", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Kappa]EBase", " ", "=", " ", 
    RowBox[{"\[Kappa]E", " ", "//", "N"}]}], ";", 
   RowBox[{"\[ScriptC]EBase", " ", "=", " ", 
    RowBox[{"\[ScriptC]E", " ", "//", "N"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.451878458983774*^9, 3.4518784993815317`*^9}, {
   3.451878786062716*^9, 3.451878825558688*^9}, {3.451929342205778*^9, 
   3.4519293462902317`*^9}, 3.4519294008840723`*^9, {3.4519294779093323`*^9, 
   3.451929485853868*^9}, {3.451929563938944*^9, 3.4519295780026417`*^9}, {
   3.451929619925234*^9, 3.451929693680624*^9}, {3.4519299241070337`*^9, 
   3.451929928411376*^9}, 3.4521080584223423`*^9, {3.4521080964608583`*^9, 
   3.4521081094256763`*^9}, 3.452108146974099*^9, {3.452108200996282*^9, 
   3.452108248061734*^9}, {3.4521095627600393`*^9, 3.452109570519038*^9}, {
   3.452109870027429*^9, 3.452109922077106*^9}, {3.452110042566852*^9, 
   3.45211006185501*^9}, {3.452110100502232*^9, 3.452110101249522*^9}, {
   3.452111128961503*^9, 3.452111136603353*^9}, 3.452201013860444*^9, {
   3.452201197356576*^9, 3.45220120429471*^9}, 3.4522476816265697`*^9, {
   3.5172456530997*^9, 3.517245673623057*^9}, {3.517245745385425*^9, 
   3.517245751576552*^9}, {3.517245792706551*^9, 3.5172458288013372`*^9}, {
   3.517245875322578*^9, 3.5172458754051867`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Solving ...\"\>"], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.5172841515681887`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Below \[ScriptM]MinBound times \[ScriptM]E after \"\>", 
   "\[InvisibleSpace]", "107", 
   "\[InvisibleSpace]", "\<\" backwards Euler iterations.\"\>"}],
  SequenceForm[
  "  Below \[ScriptM]MinBound times \[ScriptM]E after ", 107, 
   " backwards Euler iterations."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.5172841516356487`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Last Point:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.5916279694830007`", ",", "0.18762354304691212`", ",", 
     "0.27708815173434154`", ",", 
     RowBox[{"-", "36.04735224196817`"}], ",", 
     RowBox[{"-", "0.14335747370021876`"}]}], "}"}]}],
  SequenceForm[
  "Last Point:", {0.5916279694830007, 0.18762354304691212`, 
   0.27708815173434154`, -36.04735224196817, -0.14335747370021876`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151638599*^9}],

Cell[BoxData["\<\"Solving ...\"\>"], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151680359*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Above \[ScriptM]MaxBound times \[ScriptM]E after \"\>", 
   "\[InvisibleSpace]", "178", 
   "\[InvisibleSpace]", "\<\" backwards Euler iterations.\"\>"}],
  SequenceForm[
  "  Above \[ScriptM]MaxBound times \[ScriptM]E after ", 178, 
   " backwards Euler iterations."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151755145*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Last Point:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "697.7531367975785`", ",", "44.31859111954424`", ",", 
     "0.06092198958017841`", ",", 
     RowBox[{"-", "0.37172286206185823`"}], ",", 
     RowBox[{"-", "6.779062045264642`*^-7"}]}], "}"}]}],
  SequenceForm[
  "Last Point:", {697.7531367975785, 44.31859111954424, 
   0.06092198958017841, -0.37172286206185823`, -6.779062045264642*^-7}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151760071*^9}],

Cell[BoxData["\<\"Solving ...\"\>"], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151797534*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Below \[ScriptM]MinBound times \[ScriptM]E after \"\>", 
   "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" backwards Euler iterations.\"\>"}],
  SequenceForm[
  "  Below \[ScriptM]MinBound times \[ScriptM]E after ", 88, 
   " backwards Euler iterations."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151849127*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Last Point:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.8622275499900367`", ",", "0.3566335600206917`", ",", 
     "0.32707315980472024`", ",", 
     RowBox[{"-", "20.38988112067552`"}], ",", 
     RowBox[{"-", "0.19284824117008242`"}]}], "}"}]}],
  SequenceForm[
  "Last Point:", {0.8622275499900367, 0.3566335600206917, 
   0.32707315980472024`, -20.38988112067552, -0.19284824117008242`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151854192*^9}],

Cell[BoxData["\<\"Solving ...\"\>"], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151857101*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"  Above \[ScriptM]MaxBound times \[ScriptM]E after \"\>", 
   "\[InvisibleSpace]", "164", 
   "\[InvisibleSpace]", "\<\" backwards Euler iterations.\"\>"}],
  SequenceForm[
  "  Above \[ScriptM]MaxBound times \[ScriptM]E after ", 164, 
   " backwards Euler iterations."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.517284151958651*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Last Point:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "480.2784843649445`", ",", "31.361723944130745`", ",", 
     "0.061079731196664315`", ",", 
     RowBox[{"-", "0.5247781487272944`"}], ",", 
     RowBox[{"-", "1.4476866731025066`*^-6"}]}], "}"}]}],
  SequenceForm[
  "Last Point:", {480.2784843649445, 31.361723944130745`, 
   0.061079731196664315`, -0.5247781487272944, -1.4476866731025066`*^-6}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.451878464121731*^9, {3.451878503888399*^9, 3.451878532622594*^9}, 
   3.451878741003531*^9, {3.451878788293618*^9, 3.4518788485915422`*^9}, 
   3.451914374863174*^9, 3.4519214119789762`*^9, 3.451929455433587*^9, {
   3.451929489040477*^9, 3.4519295074460087`*^9}, 3.451929580281275*^9, {
   3.451929621246356*^9, 3.451929694264003*^9}, 3.4519299289912577`*^9, 
   3.451930134379161*^9, 3.4521077707814493`*^9, 3.452108007046179*^9, 
   3.452108062403878*^9, {3.4521081114179068`*^9, 3.452108147640357*^9}, {
   3.452108203169499*^9, 3.452108217673896*^9}, 3.452108248536728*^9, 
   3.4521093687007217`*^9, {3.452109777324728*^9, 3.4521097887491293`*^9}, 
   3.4521098396099453`*^9, 3.452109870806679*^9, 3.45211010182782*^9, 
   3.4521104369667597`*^9, {3.452111130294094*^9, 3.452111137502223*^9}, 
   3.452111893536231*^9, 3.452167646114653*^9, 3.452201170578519*^9, 
   3.452201204744505*^9, 3.452201459871374*^9, 3.452247715894002*^9, 
   3.4528497174117107`*^9, {3.5172455355168657`*^9, 3.517245564170432*^9}, {
   3.5172456473359547`*^9, 3.517245674748962*^9}, {3.517245746491858*^9, 
   3.5172457548182163`*^9}, {3.517245797786963*^9, 3.517245829465622*^9}, 
   3.517245877115336*^9, 3.517245937627524*^9, 3.51728415196129*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cPhaseDiagBeforeAndAfteruRise", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
    "cFuncPlotBase", ",", "cFuncPlotuHigher", ",", 
     "Stable\[ScriptM]LocusPlot", ",", "\[ScriptM]\[ScriptC]PathPlot", 
     "\[IndentingNewLine]", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Sustainable \[ScriptC] \[LongRightArrow]\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.6`", " ", "\[ScriptM]E"}], ",", 
          RowBox[{"0.98`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{
       "\"\<\[LongLeftArrow] \[ScriptC](\[ScriptM]) after unemployment rate \
increase\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.5`", " ", "\[ScriptM]E"}], ",", 
          RowBox[{"0.45`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.002", "]"}], ",", 
        RowBox[{"Dashing", "[", 
         RowBox[{"{", "0.02", "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[ScriptM]E", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[ScriptM]E", ",", 
             RowBox[{"\[ScriptC]E", "+", "0.2"}]}], "}"}]}], "}"}], "]"}]}], 
       "}"}], "]"}], "\[IndentingNewLine]", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\< \[UpperLeftArrow] Target\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "]"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\[ScriptC](\[ScriptM])\[LongRightArrow]\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.1`", " ", "\[ScriptM]E"}], ",", 
          RowBox[{"0.55`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"\[ScriptM]E", ",", "\[ScriptC]E"}], "}"}], "]"}]}], "}"}], 
      "]"}], "\[IndentingNewLine]", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
          "\[ScriptM]E", ",", 
           "\"\<\!\(\*OverscriptBox[\(\[ScriptM]\), \(\[Hacek]\)]\)\>\""}], 
          "}"}], "}"}], ",", "None"}], "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[ScriptM]MinNew", ",", 
          RowBox[{"\[ScriptM]E", "+", "4"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[ScriptC]MinNew", ",", 
          RowBox[{"\[ScriptC]E", "+", ".2"}]}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[ScriptM]\>\"", ",", "\"\<\[ScriptC]\>\""}], "}"}]}]}], 
    "]"}]}], "\[IndentingNewLine]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4518785085984898`*^9, 3.451878542461143*^9}, {
   3.45187868009194*^9, 3.45187870403836*^9}, {3.4518788761041307`*^9, 
   3.451879025877968*^9}, {3.451929434994492*^9, 3.4519294352017097`*^9}, 
   3.452201008409275*^9, 3.517283996162046*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], Thickness[Medium], LineBox[CompressedData["
1:eJwVknk81AkfgOfwY99CkVtlpuJ9XcU6fvFW36+RY2MdRScronJk3LVIkS2t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      "]]}}, {{}, {}, 
    {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJwVxn8804kfwPEZY37kU+qIQr+U/Kq2Et/k/bbxEbfrh3CFO1Qil3xD8pAk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      "]]}}, {{}, {}, 
    {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJwVjXdQ02cchxnSsrQCIkoRQ4KyFAfj5xWS7wtUQGbZIoiWpXKcelrBGEsq
Q1TWpZ6IjSKgTAVRxLqQX1HZYlBjCQhiKRCSkP2iCErpH8997rn73D1W8YdC
k7Q0NDQCF/l/P7Y9FC4s0MjrbQW3fCdE4HnBZKD2M43UZmcn5kyKIH9fakcY
ppEJbqzVbUIRUA0tq6pFNJJ2d3+Wm1gEARGnEoL5NLKi0ivKUS6CskmfkdI6
Gll+ZvaryWcR+BnyX9MjaOTVoKSg90vFcCVC9oRVRyX/GHSfPuYiBpttmy/R
t1mR8wd8vw/IE8PKXY2aRi1ryeU7PFcdGRKDdIIz7mq2hkwZnL2kYy+BQpP8
fiFhTjqOLTX0ZEvgn8TwgZtnzcgqt+WBfX0S+BrhMjlfvoLMNTiUob1uGuxF
1frDHUZkQ0GecxVzGlZ493NK6cvIM3uKH5R0TkPCxyxL7nFdsrfmi6OzpRQs
lK9GH5lqk888wo6uPSiFqaRzJbPcuVbNgmT344+l8CC5v+jGenlrTfBbzDSS
wb4pr66Lb/mtWvHOGT17ZcDtcXJ4kj0A7WLpzPN7MpgMu9787JQChOedPhfr
yGEl1euYkeU8dAiSR5Ub5HD+Puib8bTRrphOxrUoOdwp9rDW3KSHOpeUZ7PY
cvByMXZ8rfEdEk1Ve9bUyUHQvie3LcYYbapZ+tSAL4fdQcJYvW9MUWChyP7i
vBzMXXfaP5syQ1aNWD/dRgHU2dl3qZfNUd9s+quMYAWYr9Zn5XisQVctomNb
0hRQ2fubrt5yCrJm7Y/7qVwBCSdMvduTrVCmpszHoEsB9IErbPogFRU/vVZr
rlZAUeJwg8TbGr2I+/PFXksl5I4084y569Cwlaegb7sSuLqZUqWBDaqgzMVy
DishgjL5dUeiLfLwcehklSz+k7V1BM12SNvnIb7cqgR+rMm3VGsHxMxM5xqL
lNCFHs99YG5A3eM3bBuNVCB4s1MSI9mIXmYvc6xwV0FRZOHLAO9NqMFfaP44
UQVxWfQ3DwM2o0YxpdswXwVZTfWMm0u2oOSOXMXteypg7UqhRjduQTPdSRrs
ERWcElCWJKRsRe76R3LL9NTwVHZnVNfKCV2nDvM+Oalh4CTHNaXHCU3Et2oy
Y9Qw9+HAOdtsZ/Ru5GVd4Gk1KFoKoyo2u6D6zCg3vwY10LYUrb0vcEFlC/TC
X/lqSDh5dtye44p874dG62hgSGPwrKPdCdRdMmLQbIPB30TKjgACUQ+rUbIt
BorQYCjEk0AnfPTTzOwwdHF8OH6+BLKbcRll2mOwGH/yxS2cQLlhBXcZGzH8
lVf/1jKVQD8uc9/duRWDoeDcmX+5BGrJutQwRMcwWl8zNlpKINOYW2P5DAzN
me2M4XICpW59vooBGOI2aGF+NYEsPsgzyxCG22zmzx1Ni32Gb1SSF4bI9ft/
qOshkOvszILUF4PDXM6Fqj4CFfIMXcp2YNDgXZNX9BNoopqaEuKHoZb5vor7
N4EuRAa9afLHMN8baVIwRiBVU2XN8SAMvPJfDp6dIJB/3qNhu2AMlWm/d+VM
Eagivt94aNGDKH3sDBmBQo2+nKSHYKBh8eAJJYFqhcZ3pIv+qUvPNR0TSJO0
nbwaiqG31IZz9BOBdl5kWISEYSg/ul1yaI5AjQfDQ7TCMfwHrbRfnA==
      "]]}}, {{}, 
    {RGBColor[1, 0, 0], PointSize[Medium], 
     PointBox[{{4.796435450393281, 0.8388290972228006}, {4.975435173870406, 
      0.8584182483958424}, {5.135563882911107, 0.8757297720912808}, {
      5.279024452606193, 0.8910784415724631}, {5.407713490588386, 
      0.9047236724055385}, {5.523275564393472, 0.9168820784839338}, {
      5.627145060524279, 0.9277365114409694}, {5.7205791519529425`, 
      0.937442734716161}, {5.804684210007501, 0.9461344602186039}, {
      5.880437275889431, 0.9539272226460563}, {5.948703737146599, 
      0.9609214101912376}, {6.010252039418377, 0.967204670782819}, {
      6.06576604737545, 0.9728538478618207}, {6.115855516848072, 
      0.9779365560529697}, {6.161065031361059, 0.982512477226553}, {
      6.201881677026893, 0.9866344366131361}}]}, {}}, 
   InsetBox["\<\"Sustainable \[ScriptC] \[LongRightArrow]\"\>", \
{2.8778612702359685`, 1.0339098649651883`}, {1, 0}], 
   InsetBox["\<\"\[LongLeftArrow] \[ScriptC](\[ScriptM]) after unemployment \
rate increase\"\>", {2.3982177251966403`, 0.47475452983095384`}, {-1, 0}], 
   {Thickness[0.002], Dashing[{0.02}], 
    LineBox[{{4.796435450393281, 0}, {4.796435450393281, 
      1.2550100662910084`}}]}, 
   InsetBox["\<\" \[UpperLeftArrow] Target\"\>", \
{4.796435450393281, 1.0550100662910085`}, {-1, 1}], 
   InsetBox["\<\"\[ScriptC](\[ScriptM])\[LongRightArrow]\"\>", \
{0.4796435450393281, 0.5802555364600547}, {-1, 0}], 
   {GrayLevel[0], PointSize[Medium], 
    PointBox[{4.796435450393281, 1.0550100662910085`}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\[ScriptM]\"", TraditionalForm], 
    FormBox["\"\[ScriptC]\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{0, 8.79643545039328}, {0, 1.2550100662910084`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{4.796435450393281, 
      FormBox[
      "\"\\!\\(\\*OverscriptBox[\\(\[ScriptM]\\), \\(\[Hacek]\\)]\\)\"", 
       TraditionalForm]}}, None}]], "Output",
 CellChangeTimes->{
  3.451878542896171*^9, 3.4518787048546743`*^9, 3.4518787433086033`*^9, {
   3.4518788015372868`*^9, 3.451878892316905*^9}, {3.4518789315132027`*^9, 
   3.451879027901458*^9}, 3.451914376029896*^9, 3.451921413226387*^9, 
   3.45192945728749*^9, {3.451929490686996*^9, 3.451929509298955*^9}, 
   3.451929581978388*^9, {3.451929640072259*^9, 3.4519296956761627`*^9}, 
   3.451929930674466*^9, 3.45193013556973*^9, 3.452107772564165*^9, 
   3.452108008290682*^9, 3.452108065344287*^9, {3.452108114976591*^9, 
   3.452108149808688*^9}, {3.452108205813999*^9, 3.452108219847958*^9}, 
   3.452108251216765*^9, 3.452109371130451*^9, {3.452109781071178*^9, 
   3.4521097915718718`*^9}, {3.4521098436527777`*^9, 3.452109873420549*^9}, 
   3.452110105089179*^9, 3.452110442188339*^9, 3.452111140172429*^9, 
   3.452111907194017*^9, 3.4521676472792187`*^9, 3.452201173237583*^9, 
   3.45220120757097*^9, 3.452201461082259*^9, 3.452247717557342*^9, 
   3.452849718673182*^9, 3.51724553735141*^9, 3.517245656692443*^9, 
   3.517245687447381*^9, {3.517245799908868*^9, 3.517245830848425*^9}, 
   3.517245878893783*^9, 3.5172459392493258`*^9, 3.517284160339548*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
  RowBox[{"[", 
   RowBox[{"All", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.0250537586295752`", ",", "0.8388290972228006`", ",", 
   "0.8584182483958424`", ",", "0.8757297720912808`", ",", 
   "0.8910784415724631`", ",", "0.9047236724055385`", ",", 
   "0.9168820784839338`", ",", "0.9277365114409694`", ",", 
   "0.937442734716161`", ",", "0.9461344602186039`", ",", 
   "0.9539272226460563`", ",", "0.9609214101912376`", ",", 
   "0.967204670782819`", ",", "0.9728538478618207`", ",", 
   "0.9779365560529697`", ",", "0.982512477226553`", ",", 
   "0.9866344366131361`"}], "}"}]], "Output",
 CellChangeTimes->{3.5172460274219713`*^9, 3.51728416259967*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<cPhaseDiagBeforeAndAfteruRise\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4518790370500183`*^9, 3.451879081923258*^9}, {
  3.4521119088835373`*^9, 3.4521119105967417`*^9}, {3.5172839650456743`*^9, 
  3.51728396694009*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"savAfteruRiseRat", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", "r", ")"}], "/", "R"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
          RowBox[{"Table", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"Length", "[", "\[ScriptM]\[ScriptC]Path", "]"}], 
             "}"}]}], "]"}]}], ")"}]}], "-", 
       RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savAfteruRiseRat", ",", 
    RowBox[{"savAfteruRiseRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savAfteruRiseRat", ",", 
    RowBox[{"savAfteruRiseRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savAfteruRiseRat", ",", 
    RowBox[{"savAfteruRiseRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savAfteruRiseRat", ",", 
    RowBox[{"savAfteruRiseRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timePath", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "savAfteruRiseRat", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"savAfteruRisePathPlot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"timePath", ",", "savAfteruRiseRat"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Black"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"savAfteruRisePath", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"savAfteruRisePathPlot", ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"5", ",", "\"\<t\>\""}], "}"}], "}"}], ",", "None"}], 
      "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", "\"\<\[ScriptS]\>\""}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         RowBox[{"Length", "[", "timePath", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", 
         RowBox[{
          RowBox[{"Max", "[", "savAfteruRiseRat", "]"}], "+", "0.01`"}]}], 
        "}"}]}], "}"}]}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.451866126028428*^9, 3.4518661988585043`*^9}, {
   3.4518662393474503`*^9, 3.4518662891032143`*^9}, {3.451866510813486*^9, 
   3.4518665949165497`*^9}, {3.45186668080405*^9, 3.451866859623073*^9}, {
   3.451877979024988*^9, 3.451877999386065*^9}, {3.452109736049985*^9, 
   3.452109769355074*^9}, {3.4521118736457357`*^9, 3.452111877429319*^9}, {
   3.4522011393952723`*^9, 3.452201161839464*^9}, {3.452247665232881*^9, 
   3.4522476787534657`*^9}, {3.517245473338976*^9, 3.517245494996352*^9}, {
   3.517245918048677*^9, 3.5172459185343933`*^9}, 3.517245993683001*^9, 
   3.5172460567421703`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {GrayLevel[0], PointSize[Medium], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7B2ec04/+mSrPVTAAZXPgcYXQOOLoPElHKyC
4219Ui5C+TIOp27d2Huk4gKUr+Dgc+DNI8ng81C+kkPFjCnpwk/PQvkqDhwv
ZX2OLjgD5as5SFx08lrRcBrK13BIibH8KdNwCsrXciip8LtvPfsklK/jYKF9
aOnGcyegfD0HmwX7ri8Wh/ENHCSuTjk+u/g4lG/owDFlwvfSB8egfCMHCxfh
RyExML6xg0nYnYBpT49C+SYOLxx2rTlVBeObOvx4uezaWqmj9gAMXmMw
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"\[ScriptS]\"", TraditionalForm]},
  AxesOrigin->{-3, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{-3, 21}, {0., 0.2817466925944795}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Ticks->{{{5, 
      FormBox["\"t\"", TraditionalForm]}}, None}]], "Output",
 CellChangeTimes->{
  3.451878003418573*^9, 3.45187852151304*^9, 3.4518787300260878`*^9, 
   3.451914373025298*^9, 3.451921410203561*^9, 3.451929452795191*^9, 
   3.451929505426581*^9, 3.451930132405404*^9, 3.452107766373877*^9, 
   3.4521079534007072`*^9, 3.452108004924798*^9, 3.452108133957602*^9, 
   3.452109364303089*^9, 3.452109707877503*^9, {3.452109751416874*^9, 
   3.452109770768965*^9}, 3.452110091820181*^9, 3.452110321525128*^9, 
   3.4521104315984163`*^9, 3.4521111231900587`*^9, {3.452111227851334*^9, 
   3.4521112577534933`*^9}, {3.4521118790052347`*^9, 3.4521118869997387`*^9}, 
   3.452167645095051*^9, 3.4522011210730963`*^9, {3.452201152563283*^9, 
   3.452201162437416*^9}, 3.452201458107367*^9, 3.452247658083378*^9, 
   3.452247713638658*^9, 3.4528497157745323`*^9, 3.517245055420209*^9, 
   3.517245541669868*^9, 3.517245835303368*^9, 3.517245882586645*^9, {
   3.517245920261239*^9, 3.517245942423524*^9}, {3.5172459819387493`*^9, 
   3.517245994897029*^9}, 3.517246057471977*^9, 3.517284172970895*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<savAfteruRisePath\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{
  3.4518669981886663`*^9, {3.451877591176442*^9, 3.4518775923280277`*^9}, 
   3.5172455060729113`*^9, {3.517245904112484*^9, 3.517245954227949*^9}, 
   3.517246068855043*^9}],

Cell[CellGroupData[{

Cell[BoxData["savAfteruRiseRat"], "Input",
 CellChangeTimes->{{3.5172843759288063`*^9, 3.517284389512933*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.08552203118770496`", ",", "0.08552203118770496`", ",", 
   "0.08552203118770496`", ",", "0.08552203118770496`", ",", 
   "0.08552203118770496`", ",", "0.2717466925944795`", ",", 
   "0.2573711256003831`", ",", "0.24472354488671255`", ",", 
   "0.23355333860053284`", ",", "0.22365633217470582`", ",", 
   "0.2148638117411188`", ",", "0.20703470391410683`", ",", 
   "0.2000498619426626`", ",", "0.19380779832530393`", ",", 
   "0.18822143587499507`", ",", "0.1832155918615761`", ",", 
   "0.1787250002682017`", ",", "0.17469273604231872`", ",", 
   "0.17106894443775078`", ",", "0.1678098052402739`", ",", 
   "0.16487668019347246`"}], "}"}]], "Output",
 CellChangeTimes->{3.517284390131304*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
  RowBox[{"[", 
   RowBox[{"All", ",", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.517284297975095*^9, 3.517284300067939*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.0250537586295752`", ",", "0.8388290972228006`", ",", 
   "0.8584182483958424`", ",", "0.8757297720912808`", ",", 
   "0.8910784415724631`", ",", "0.9047236724055385`", ",", 
   "0.9168820784839338`", ",", "0.9277365114409694`", ",", 
   "0.937442734716161`", ",", "0.9461344602186039`", ",", 
   "0.9539272226460563`", ",", "0.9609214101912376`", ",", 
   "0.967204670782819`", ",", "0.9728538478618207`", ",", 
   "0.9779365560529697`", ",", "0.982512477226553`", ",", 
   "0.9866344366131361`"}], "}"}]], "Output",
 CellChangeTimes->{3.5172841948402243`*^9, 3.51728430066026*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"cRatAfteruRiseRat", "=", 
   RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"PrependTo", "[", 
     RowBox[{"cRatAfteruRiseRat", ",", 
      RowBox[{"cRatAfteruRiseRat", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", "4", "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timePath", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "cRatAfteruRiseRat", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cRatAfteruRisePathPlot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"timePath", ",", "cRatAfteruRiseRat"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Black"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"cRatAfteruRisePath", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"cRatAfteruRisePathPlot", ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"5", ",", "\"\<t\>\""}], "}"}], "}"}], ",", "None"}], 
      "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", "\"\<\[ScriptC]\>\""}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         RowBox[{
          RowBox[{"Length", "[", "timePath", "]"}], "+", "1"}]}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"0.`", ",", 
         RowBox[{
          RowBox[{"Max", "[", "cRatAfteruRiseRat", "]"}], "+", "0.01`"}]}], 
        "}"}]}], "}"}]}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.451866126028428*^9, 3.4518661988585043`*^9}, {
   3.4518662393474503`*^9, 3.4518662891032143`*^9}, {3.451866510813486*^9, 
   3.4518665949165497`*^9}, {3.45186668080405*^9, 3.451866859623073*^9}, {
   3.451877979024988*^9, 3.451877999386065*^9}, {3.452109736049985*^9, 
   3.452109769355074*^9}, {3.4521118736457357`*^9, 3.452111877429319*^9}, {
   3.4522011393952723`*^9, 3.452201161839464*^9}, {3.452247665232881*^9, 
   3.4522476787534657`*^9}, {3.517245473338976*^9, 3.517245494996352*^9}, {
   3.517245918048677*^9, 3.5172459185343933`*^9}, 3.517245993683001*^9, 
   3.5172460567421703`*^9, {3.517284065902536*^9, 3.517284083764057*^9}, {
   3.5172842515334167`*^9, 3.5172842618722887`*^9}, {3.517284344201482*^9, 
   3.517284353079298*^9}, {3.517284447491879*^9, 3.517284490154001*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {GrayLevel[0], PointSize[Medium], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7BO95Y/OS/tgDxVwQOVzoPEF0PgiaHwJB16t
ArkN119B+TIOu0896daseA3lKzisrs8o/MX6BspXchDTm/5+WzOMr+LAcliG
v/4zjK/mkCKwRlQy/C2Ur+HAbPavimUDjK/lsDjw/fP2/zC+jsMU245ju93e
Qfl6Du/fMCRNaoPxDRxWtd50vLcfxjd0+DZvo2n4ZxjfyMEprDtlnuJ7KN/Y
Yea7nbMcvWF8Ewc5482M+wpgfFOHbd2nE5smvbcHAMO4YG8=
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"\[ScriptC]\"", TraditionalForm]},
  AxesOrigin->{-3, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{-3, 22}, {0., 1.0350537586295752`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Ticks->{{{5, 
      FormBox["\"t\"", TraditionalForm]}}, None}]], "Output",
 CellChangeTimes->{
  3.451878003418573*^9, 3.45187852151304*^9, 3.4518787300260878`*^9, 
   3.451914373025298*^9, 3.451921410203561*^9, 3.451929452795191*^9, 
   3.451929505426581*^9, 3.451930132405404*^9, 3.452107766373877*^9, 
   3.4521079534007072`*^9, 3.452108004924798*^9, 3.452108133957602*^9, 
   3.452109364303089*^9, 3.452109707877503*^9, {3.452109751416874*^9, 
   3.452109770768965*^9}, 3.452110091820181*^9, 3.452110321525128*^9, 
   3.4521104315984163`*^9, 3.4521111231900587`*^9, {3.452111227851334*^9, 
   3.4521112577534933`*^9}, {3.4521118790052347`*^9, 3.4521118869997387`*^9}, 
   3.452167645095051*^9, 3.4522011210730963`*^9, {3.452201152563283*^9, 
   3.452201162437416*^9}, 3.452201458107367*^9, 3.452247658083378*^9, 
   3.452247713638658*^9, 3.4528497157745323`*^9, 3.517245055420209*^9, 
   3.517245541669868*^9, 3.517245835303368*^9, 3.517245882586645*^9, {
   3.517245920261239*^9, 3.517245942423524*^9}, {3.5172459819387493`*^9, 
   3.517245994897029*^9}, 3.517246057471977*^9, {3.517284468799947*^9, 
   3.51728449079976*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<cRatAfteruRisePath\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{
  3.4518669981886663`*^9, {3.451877591176442*^9, 3.4518775923280277`*^9}, 
   3.5172455060729113`*^9, {3.517245904112484*^9, 3.517245954227949*^9}, 
   3.517246068855043*^9, 3.5172840859916*^9, 3.5172842644121237`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "cE", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cE", "[", "m_", "]"}], ":=", " ", 
    RowBox[{"cEInterp", "[", 
     RowBox[{"m", "+", "DebtLimPDV"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SimGeneratePath", "[", 
   RowBox[{"\[ScriptM]E", ",", "100"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"cFuncPlotNew", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"cE", "[", "\[ScriptM]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[ScriptM]", ",", 
        RowBox[{"-", "DebtLimPDV"}], ",", "\[ScriptM]MaxMax"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Thickness", "[", "0.002", "]"}]}], "}"}]}]}], "]"}]}], 
   ";"}]}], "\n", 
 RowBox[{
  RowBox[{"\[ScriptM]\[ScriptC]PathPlot", " ", "=", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{"\[ScriptM]\[ScriptC]Path", ",", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "\[ScriptM]\[ScriptC]Path", "]"}], "-", 
          "1"}], ")"}]}]}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[ScriptM]MinNew", ",", "\[ScriptM]MaxNew"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "20"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[ScriptC]MinNew", ",", "\[ScriptC]MaxNew"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2.`"}], "}"}]}], ";", 
  RowBox[{"TractableBufferStockTarget", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"cFuncPlotBase", ",", "Stable\[ScriptM]LocusPlot", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Perm Inc \[LongRightArrow]\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.6`", " ", "\[ScriptM]E"}], ",", 
          RowBox[{"0.98`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\[LongLeftArrow] \[ScriptC](\[ScriptM])\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"0.9`", " ", "\[ScriptM]E"}], ",", 
          RowBox[{"0.85`", " ", "\[ScriptC]E"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[ScriptM]MinNew", ",", 
          RowBox[{"\[ScriptM]E", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[ScriptC]MinNew", ",", 
          RowBox[{"\[ScriptC]E", "+", "rBase", "+", "0.01"}]}], "}"}]}], 
       "}"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[ScriptM]\>\"", ",", "\"\<\[ScriptC]\>\""}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PhaseDiagramDebtLimRisePlot", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
    "cFuncPlotNew", ",", "cFuncPlotBase", ",", "\[ScriptM]\[ScriptC]PathPlot",
      ",", "Stable\[ScriptM]LocusPlot", "\[IndentingNewLine]", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"\[ScriptM]EBase", ",", "\[ScriptC]EBase"}], "}"}], "]"}]}],
        "}"}], "]"}], "\[IndentingNewLine]", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\[UpperLeftArrow] Orig Target \>\"", ",", 
        RowBox[{"{", 
         RowBox[{"\[ScriptM]EBase", ",", 
          RowBox[{"0.98`", " ", "\[ScriptC]EBase"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{
       "\"\< \[LongLeftArrow] Orig \[ScriptC](\[ScriptM]) \>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"1.35`", " ", "\[ScriptM]EBase"}], ",", 
          RowBox[{"1.2`", " ", "\[ScriptC]EBase"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<  New \[ScriptC](\[ScriptM]) \[LongRightArrow] \>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[ScriptM]EBase", "+", "1"}], ",", 
          RowBox[{"cE", "[", 
           RowBox[{"\[ScriptM]EBase", "+", "1"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "DebtLimPDV"}], ",", "\[ScriptM]MaxNew"}], "}"}], ",", 
        
        RowBox[{"{", 
         RowBox[{"\[ScriptC]MinNew", ",", 
          RowBox[{"\[ScriptC]MaxNew", "+", "0.02"}]}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[ScriptM]\>\"", ",", "\"\<\[ScriptC]\>\""}], "}"}]}]}], 
    "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.414626224640168*^9, 3.4146262281168127`*^9}, {
   3.414626446416924*^9, 3.414626447103096*^9}, {3.414626744546838*^9, 
   3.414626747466916*^9}, {3.423299776442008*^9, 3.4232997967943687`*^9}, 
   3.42329990979178*^9, 3.423300558978189*^9, {3.4518098458286047`*^9, 
   3.4518098517937393`*^9}, {3.4518545586369457`*^9, 3.4518545608078203`*^9}, 
   3.45210778016403*^9, {3.4522012428127937`*^9, 3.452201248337761*^9}, {
   3.452848918652616*^9, 3.452848937742028*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<PhaseDiagramDebtLimRisePlot\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "PhaseDiagramDebtLimRisePlot", "]"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4518099634782133`*^9, 3.451809981385398*^9}, {
  3.4518100142489243`*^9, 3.451810018031461*^9}, {3.451957940900217*^9, 
  3.451957950737563*^9}, {3.45220130919279*^9, 3.452201310014441*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJwVyXk81PkfwPExRkJNXyWDhmYMxorKkSLj83Y8ppyZ0bKOxGDRVkI8NneN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      "]]}}, {{}, {}, 
    {GrayLevel[0], Thickness[Medium], LineBox[CompressedData["
1:eJwVknk81AkfgOfwY99CkVtlpuJ9XcU6fvFW36+RY2MdRScronJk3LVIkS2t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      "]]}}, 
   {RGBColor[1, 0, 0], PointSize[Medium], PointBox[CompressedData["
1:eJwV0Hk01G0UB3ANkuodNZaZp6NFQgul0qIcVyrtCm8zTlSImkoL4VSWFElh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     "]]}, {{}, {}, 
    {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJwVjXdQ02cchxnSsrQCIkoRQ4KyFAfj5xWS7wtUQGbZIoiWpXKcelrBGEsq
Q1TWpZ6IjSKgTAVRxLqQX1HZYlBjCQhiKRCSkP2iCErpH8997rn73D1W8YdC
k7Q0NDQCF/l/P7Y9FC4s0MjrbQW3fCdE4HnBZKD2M43UZmcn5kyKIH9fakcY
ppEJbqzVbUIRUA0tq6pFNJJ2d3+Wm1gEARGnEoL5NLKi0ivKUS6CskmfkdI6
Gll+ZvaryWcR+BnyX9MjaOTVoKSg90vFcCVC9oRVRyX/GHSfPuYiBpttmy/R
t1mR8wd8vw/IE8PKXY2aRi1ryeU7PFcdGRKDdIIz7mq2hkwZnL2kYy+BQpP8
fiFhTjqOLTX0ZEvgn8TwgZtnzcgqt+WBfX0S+BrhMjlfvoLMNTiUob1uGuxF
1frDHUZkQ0GecxVzGlZ493NK6cvIM3uKH5R0TkPCxyxL7nFdsrfmi6OzpRQs
lK9GH5lqk888wo6uPSiFqaRzJbPcuVbNgmT344+l8CC5v+jGenlrTfBbzDSS
wb4pr66Lb/mtWvHOGT17ZcDtcXJ4kj0A7WLpzPN7MpgMu9787JQChOedPhfr
yGEl1euYkeU8dAiSR5Ub5HD+Puib8bTRrphOxrUoOdwp9rDW3KSHOpeUZ7PY
cvByMXZ8rfEdEk1Ve9bUyUHQvie3LcYYbapZ+tSAL4fdQcJYvW9MUWChyP7i
vBzMXXfaP5syQ1aNWD/dRgHU2dl3qZfNUd9s+quMYAWYr9Zn5XisQVctomNb
0hRQ2fubrt5yCrJm7Y/7qVwBCSdMvduTrVCmpszHoEsB9IErbPogFRU/vVZr
rlZAUeJwg8TbGr2I+/PFXksl5I4084y569Cwlaegb7sSuLqZUqWBDaqgzMVy
DishgjL5dUeiLfLwcehklSz+k7V1BM12SNvnIb7cqgR+rMm3VGsHxMxM5xqL
lNCFHs99YG5A3eM3bBuNVCB4s1MSI9mIXmYvc6xwV0FRZOHLAO9NqMFfaP44
UQVxWfQ3DwM2o0YxpdswXwVZTfWMm0u2oOSOXMXteypg7UqhRjduQTPdSRrs
ERWcElCWJKRsRe76R3LL9NTwVHZnVNfKCV2nDvM+Oalh4CTHNaXHCU3Et2oy
Y9Qw9+HAOdtsZ/Ru5GVd4Gk1KFoKoyo2u6D6zCg3vwY10LYUrb0vcEFlC/TC
X/lqSDh5dtye44p874dG62hgSGPwrKPdCdRdMmLQbIPB30TKjgACUQ+rUbIt
BorQYCjEk0AnfPTTzOwwdHF8OH6+BLKbcRll2mOwGH/yxS2cQLlhBXcZGzH8
lVf/1jKVQD8uc9/duRWDoeDcmX+5BGrJutQwRMcwWl8zNlpKINOYW2P5DAzN
me2M4XICpW59vooBGOI2aGF+NYEsPsgzyxCG22zmzx1Ni32Gb1SSF4bI9ft/
qOshkOvszILUF4PDXM6Fqj4CFfIMXcp2YNDgXZNX9BNoopqaEuKHoZb5vor7
N4EuRAa9afLHMN8baVIwRiBVU2XN8SAMvPJfDp6dIJB/3qNhu2AMlWm/d+VM
Eagivt94aNGDKH3sDBmBQo2+nKSHYKBh8eAJJYFqhcZ3pIv+qUvPNR0TSJO0
nbwaiqG31IZz9BOBdl5kWISEYSg/ul1yaI5AjQfDQ7TCMfwHrbRfnA==
      "]]}}, 
   {PointSize[0.015], PointBox[{4.796435450393281, 1.0550100662910085`}]}, 
   InsetBox["\<\"\[UpperLeftArrow] Orig Target \"\>", \
{4.796435450393281, 1.0339098649651883`}, {-1, 1}], 
   InsetBox["\<\" \[LongLeftArrow] Orig \[ScriptC](\[ScriptM]) \"\>", \
{6.475187858030929, 1.26601207954921}, {-1, 0}], 
   InsetBox["\<\"  New \[ScriptC](\[ScriptM]) \[LongRightArrow] \"\>", \
{5.796435450393281, 2.099365615580491}, {1, 0}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\[ScriptM]\"", TraditionalForm], 
    FormBox["\"\[ScriptC]\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{-9.999999999999993, 20}, {0, 2.02}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Ticks->None]], "Output",
 CellChangeTimes->{
  3.451809982490657*^9, 3.451810026613759*^9, 3.45181015308397*^9, 
   3.4518776081205053`*^9, 3.451878034040155*^9, 3.451914382924906*^9, 
   3.4519214198863277`*^9, 3.451930142130576*^9, 3.452107796393721*^9, 
   3.4521082785608263`*^9, 3.452108335233342*^9, {3.452108381218129*^9, 
   3.452108404407145*^9}, 3.452111153589656*^9, 3.452111920141758*^9, 
   3.452167655000977*^9, 3.452201224643742*^9, {3.452201260148554*^9, 
   3.45220132133361*^9}, 3.452201466958891*^9, 3.45224772817325*^9, 
   3.4528497221040897`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"HowMany", "=", "75"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[ScriptM]Path", "=", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "\[ScriptM]\[ScriptC]Path", "]"}], 
      "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
     "HowMany"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[ScriptC]Path", "=", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Transpose", "[", "\[ScriptM]\[ScriptC]Path", "]"}], 
      "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
     "HowMany"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MPCPath", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"cE", "[", 
         RowBox[{"#1", "+", 
          RowBox[{"10", " ", "\[CurlyEpsilon]"}]}], "]"}], "-", 
        RowBox[{"cE", "[", 
         RowBox[{"#1", "-", 
          RowBox[{"10", " ", "\[CurlyEpsilon]"}]}], "]"}]}], 
       RowBox[{"20", " ", "\[CurlyEpsilon]"}]], "&"}], ")"}], "/@", 
    RowBox[{"Rest", "[", "\[ScriptM]Path", "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"\[ScriptM]Path", ",", "\[ScriptM]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"\[ScriptC]Path", ",", "\[ScriptC]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"MPCPath", ",", "\[Kappa]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"\[ScriptM]Path", ",", "\[ScriptM]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"\[ScriptC]Path", ",", "\[ScriptC]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"MPCPath", ",", "\[Kappa]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"\[ScriptM]Path", ",", "\[ScriptM]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"\[ScriptC]Path", ",", "\[ScriptC]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"MPCPath", ",", "\[Kappa]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"MPCPath", ",", "\[Kappa]EBase"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"timePath", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "\[ScriptC]Path", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"\[ScriptC]PathPlot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"timePath", ",", "\[ScriptC]Path"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[ScriptM]PathPlot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"timePath", ",", "\[ScriptM]Path"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MPCPathPlot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"timePath", ",", "MPCPath"}], "}"}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.413723819708805*^9, 3.4137238230162477`*^9}, {
  3.423299608069623*^9, 3.423299609054262*^9}, {3.4232997629877167`*^9, 
  3.4232997636622887`*^9}, {3.423300582730242*^9, 3.4233005836896343`*^9}, {
  3.4518093705917892`*^9, 3.451809375084947*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cPathAfterDebtLimRise", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"\[ScriptC]PathPlot", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"4", ",", "\"\<0\>\""}], "}"}], "}"}], ",", "None"}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Time\>\"", ",", "\"\<\[ScriptC]\>\""}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "HowMany"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", 
          RowBox[{
           RowBox[{"Max", "[", "\[ScriptC]Path", "]"}], "+", "0.1`"}]}], 
         "}"}]}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mPathAfterDebtLimRise", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"\[ScriptM]PathPlot", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dashing", "[", 
         RowBox[{"{", "0.01`", "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
             "timePath", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{"\[ScriptM]EBase", "-", "DebtLimPDV", "-", "2.85`"}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"timePath", "\[LeftDoubleBracket]", 
              RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ",", 
             RowBox[{"\[ScriptM]EBase", "-", "DebtLimPDV", "-", "2.85`"}]}], 
            "}"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\[UpArrow]\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "timePath", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"timePath", "\[LeftDoubleBracket]", 
              RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}], ")"}]}], ",", 
          RowBox[{"\[ScriptM]EBase", "-", "DebtLimPDV", "-", "0.55`"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{
       "\"\<\\!\\(\\*OverscriptBox[\\(\[ScriptM]\\), \\(_\\)]\\)-d\>\"", ",", 
        
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "timePath", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"timePath", "\[LeftDoubleBracket]", 
              RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}], ")"}]}], ",", 
          RowBox[{"\[ScriptM]EBase", "-", "DebtLimPDV", "-", "0.85`"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"4", ",", "\"\<0\>\""}], "}"}], "}"}], ",", "None"}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Time\>\"", ",", "\"\<\[ScriptM]\>\""}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "HowMany"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "DebtLimPDV"}], ",", 
          RowBox[{
           RowBox[{"Max", "[", "\[ScriptM]Path", "]"}], "+", "1"}]}], "}"}]}],
        "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MPCPathAfterDebtLimRise", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"MPCPathPlot", ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dashing", "[", 
         RowBox[{"{", "0.01`", "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
             "timePath", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", "\[Kappa]"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"timePath", "\[LeftDoubleBracket]", 
              RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ",", 
             "\[Kappa]"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<\[UpArrow]\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "timePath", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"timePath", "\[LeftDoubleBracket]", 
              RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}], ")"}]}], ",", 
          "\[Kappa]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Perfect Foresight MPC\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "timePath", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "+", 
             RowBox[{"timePath", "\[LeftDoubleBracket]", 
              RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}], ")"}]}], ",", 
          FractionBox[
           RowBox[{"\[Kappa]", " ", "4"}], "5"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"4", ",", "\"\<0\>\""}], "}"}], "}"}], ",", "None"}], 
       "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Time\>\"", ",", "\"\<\[Kappa](\[ScriptM])\>\""}], "}"}]}],
      ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "HowMany"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0.15`"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\n"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.414063208761087*^9, 3.41406323141257*^9}, {
   3.414626768600664*^9, 3.4146267735244207`*^9}, {3.4146268170510683`*^9, 
   3.41462681941683*^9}, 3.4232997146440897`*^9, {3.423301007196418*^9, 
   3.42330101029316*^9}, {3.44795697579627*^9, 3.4479569786409903`*^9}, 
   3.447957023036353*^9, 3.447957054253059*^9, {3.447957103233692*^9, 
   3.447957118064385*^9}, 3.451809415472859*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<cPathAfterDebtLimRise\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "cPathAfterDebtLimRise", 
  "]"}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4518094277385273`*^9, 3.451809496487637*^9}, 
   3.451809739005718*^9, {3.451810047297975*^9, 3.4518100532858057`*^9}, 
   3.451810099460393*^9}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxd0H9MzHEcx/EvHVoo7AotlJqf6Zcj6tSr4oq46m7rWsuvCrcJ/ZAZyflV
LZXKj1bKj2uZOyEJm8yPq51fqRYiP05Yy48ckVPnlKzP+w99t8++e3yfn9c/
X4foLZJ1QzmOE/eff++B55svv9pLKHn7zZd9wP82H+Qxg8xHk3bfMdupHAY8
AUX5rd0zu3pZt4N1cnBN9NU/zPaw0Fqcdcs0MU/FUPljD/3m38xOWOPon9Eb
Y2Sehk2aXbvq5D3MM1Ave15yP6WbeRbezLGbsunkL2ZnNJp+az0aDcwuUKZG
aQstyW6I/5iW5xj5k9kdL1qu3ZRUdjF7wOlOmUFlQ54L322/zM6l/WAWIG+/
lVXzEPI8eHoVjFOlf2eej+xbtfknx5M9UR+pKPG41Mm8AKINpfwWKXkhwl9N
8jHvo//pBfHdrFxBJdkbgqD1F5riyEI4f29LjXAhL0IFX1qW0vGV2QcyBwOP
yyD7wlZb3entQgY+yWUCoU4/YAXwZFz1sIkFzJwflPt5rt0y6n4wpn54MNqe
uj9azJTlxfovrPtjRP29rQYNMxeANles3llMPQD6ac3NhTuoL0aiMvbloyjq
i2HZqRKd8qe+BB0NL41ls6kvQUZrEm/3eOoibJvIv/Z0GHUR3IzahysNHawH
ImtCzIHHH5gVgUiNP6gzvqIeBFmRquZEE/UgjF0bHpl7n/pSqJM6ws/cob4U
tbrENTeuU1+GnPTSvZVV1JdB05B2Pu4i9WAozT77NampB6PTqFM9OkN9OVR6
kSm4lPpyvJtTohaeor4CfSN+eOaVUF8B133ibuFx6mJYyLOfCQqpi2EZxZu+
pYB6CExT7BPeH6UegqiaVZLMI9RDYek8XLbyMDNCsVU86nV4Pt0PxZDTl3sS
8phvh6IuZ2O0Opf2Ydijy40wHaJ9GOymXymIJSvCoE6fLGrNoX0Y3nYtbI8j
cxL0FGtCzMmQIMFdfrwim/YS2MhrHWPJtyUYWZe83YHMSeFl7R3RnkV7KXga
vbqKrJBCWC5Kyej3X0f6gTk=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"\[ScriptC]\"", TraditionalForm]},
  AxesOrigin->{-3, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{-3, 75}, {0., 2.116652274986748}},
  PlotRangeClipping->True,
  Ticks->{{{4, 
      FormBox["\"0\"", TraditionalForm]}}, None}]], "Output",
 CellChangeTimes->{3.451809498388364*^9, 3.451809740914597*^9, 
  3.451810054692822*^9, 3.4518101661900578`*^9, 3.4518776220680428`*^9, 
  3.4518780397745857`*^9, 3.451914387170855*^9, 3.451921422373118*^9, 
  3.451930145103671*^9, 3.45210780771216*^9, 3.452108415989367*^9, 
  3.452167658598818*^9, 3.452201337006262*^9, 3.4522014700097713`*^9, 
  3.452247741852215*^9, 3.4528497249324617`*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXU2MI0cV7rXnZxcl2SURuSDQHhASAvUp4sCPoFF+ECJqBCeEIzFaYe0K
onQ24ccnhIWAPoFPmAvOxUnIoAiDRJ86RD6ALy0iS1FfDOpLc2iJPrRQLOSF
R3V19Y93pqrelO1eD+qRpj2u/t573/veqyp71zP17MnLt7/1/MnLd26d3Hzm
7ol1+86tl24+/cJdMtS+ommttzTtyu9vagfkZ9C0tUvx9XZ62c7AF+lDG5I4
hjiOIE6WFdB3M9DTDASJD3ZHp2xa9NoGwxrCIqHoiuHdzPAp+nANYOmDlaUB
AzegkGg2pM813YaQb9yGmW1QoN53Uw50zO1lY9YkOGv4JH04IFHn0KFRdThd
LNtsOPEGWWCtB8GqtIYX182TOSOodcBbQm6+Ciag02ETZgnfPJ7lYSiufYYU
kcKLuebewCxYLlYVc69innDN/dMeU5cmeZ75yBeYjzrnk/dQ5EvpTPAq5skM
TAR5iFwmsQHTuDCvFmS+5CsPEMPAyMJ0x4vcvFDUcqBa9tw8b9aicKl0OYZU
rctayQlXZ3sumyLHMB0w4YwenE7G0NVZutOwYvRSZvQMfTiEyJ/CyO6DZVlg
9QbgLuIK+LkirRXEYQBBEEAYJY9lPkrcT+hAmm0C4062ZhzQ6yF0RvMCt1yc
puoSpMauFrzz7vpYxz6Fcd9cm+lpNU69GfSNHHdANVqkpUjm0DcLc93sgxdT
kbUb9/P8Gcs69idgsG7QDBv8eEWzBO195BLB0MzuGT0HimonZQPa06hF4Q9B
6NpFv02jAgunlp656Lus5AH0dZbRIc2o0zEL01nMpZsSWxRrmDmcHzG158MO
G/K0VgFNYGQWfZ4PF/1rDgkAWkyHOZtr5sCjAUO3zxgeg2k7kM+TVeyn5En/
TtJktOt8pmV44vQM0wGPaXyGqVFherXqgXbjhMmrmaMUli/O2SpBZ37tJI/v
I5kUbWRPY+3xjM1jGRW6p5JLN71c3y2va1xeg+kC4iiCKAqJ5yiKSLQwDCFe
ZvPneoVzNsFyKbUnzhkrlf70ZhkN50XjLovGHaUz8f7GNVjjzmyT6M9WANsr
KD1SawYh9NgstcbzbPhhCJ1esXW4Qb6alB1ss1Ujr11n7Jcu43w3orP8xpaz
yZa8q7AKXbBMswzFVF0GTrppFktr14bJZJiunGzsOvSGZLW28x2blo7FXBYZ
jrwQVssARl39vPVuy+k8RMRdQjBP9zWLpqTbMyZ6Av5sArZlUg6u7wHpm1ax
XVkwT1awcOzULBs+ogt4dcdPg7qDbrGF6V2yadKkRQmV1s+zu6lC7nAE/hLO
nQQkoWxVOyKvfScwnoalD5JIFC8P2O1VkhSvKpZJTCZyXM6VLFA6y8Mo1o5Y
oNUyhZGZH1PTRy9GPIEBQfS9REycvFa2yFCfqk9evaBjPArFKmX0YRbELL24
3JgHszxhWExHtMz51jAdWmAYXZj4yccvnFf2mom8DMi2ado6lXcQen+mXdDp
CnzXgYnjkIXYIdcjcCYTcOcRvefSuWPCeB6j/L7RgBpQA2pADagBNaAG1IAa
UANqQA2oATWgBtSAGlADakAN6D7QH+iPh3Dv3n/gtVffgR98z6GP5LnWFtxr
KdrVfa/huU8829V77NMW/N788d7xF99Ln3/us78qvslz4b2Wol3d9xqe+8Sz
Xb0nnUPf2aN+f1C1S7lX76Vrj+heS9Gu7nsNz33i2a7ek87L5xTn3j7NkwdV
831aWy7LGtjw3O0++6zifN40t32YXw+qV/bptf9leY/S8Nzte9andjDXN92D
92Hu1d1H/5bU6ZMb8tlmnTZdW7epGxXnYxLxdEWBMA25i41JSYTPS0T46A66
BLOrbz3RryAT3WbVMJ3AJfxNCeEPI9TYpsKieUgJ3ZYQfnzDVlJS8ftIUqpl
5wb+oSTwIzsoH3X8U0ngY0SNt14GLCnRLFIqw8/5gf+rWAGRSNTzL+Uxt7kJ
ymK+t2GncWP+Wh7zonlS61flfpX4CvzGCI24fN+U+1WaNAi/5+lAEX/k2/5j
k1wRfpVyRfjl5voW3/bvm+SK8KuUq8DvBxF8t/nm4jWZtn+Wc1Vdyy5q9woi
f24tEXnU9Y+/ryC04fbOHtaD2zve/vS5SHMZ178qxsT65XJ6V27L1R5hqxL3
L5togfDL5fQ3uS1XC4StStw/baIFwi+XUyi35WqBsN0kLjdfga0js/2n3JbL
GWHL1WrHcVXy/Z3M9l9yWy5nhC1Xqx3HVckXii/BxwNflwW4J7flJoaw5Qq6
47gq+aIEFb1KKx0cyh1ws8M64EpbGwNlDVBKo0BDFJWH5Q7EYiAciMtRBwNl
DVBKbw/0CxTfD8gdiBVDOBDXrA4GyhqglEaB8j8cJqbyIbkDsRgIB+Jy1MFA
WQOU0jWDfoRK6iNyB2JZEQ7Eha2DgbIGKKVrBvVQSX1C7kAsK8KBuLB1MFDW
AKV0zaAXUUk9IXcglhXhQFzYOhgoa4BS+tKC7qDk+YzcgbhACAfiFqmDgbIG
KKUvLegEJc+TcgfiAiEciFukDgbKGqCUvrSgr6Pk+bLcgbhACAfiFqmDgbIG
KKUbkPZVepUJ/TW5A3GpEQ7EzVYHA2UNUEo3IO1L9CoT+htyB+JSIxyIm60O
BsoaoJRuQDjQF+hVVo1bcgfifkA4EHdkHQyUNUAp3YBwoE/Rq6wa35Y7EPcD
woG4I+tgoKwBSukG1IDOAZUDb///DWQna6T/+7uEhTcF152C5wfpn+2vgH+b
gbNfE0g/ThSm5xWkslVOxjFh7GWfrCkN36gaXoXFmJ4zQr8Hrg9ROM+P2IGe
E3DsDsDP7cxh9UCBwO2TYRvitZi/WbfNT8hgJ87kv2EYhVF+VkHF9vV122CS
H5nRBb96XtKb67hVmJ+HpcOkep7WGi5VeQUOO4xCZ0fY5MnEYcgnlJXpGj37
p8sE7BeCJfS4D2MwpQ7PGN9g6kM0K4ytwRjGA6tg7YSrM3bvpw/HhHQE7qgP
BjvHSTcMMDv0dKOzwcqBXbatduV/Y+imdA==\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<mPathAfterDebtLimRise\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "mPathAfterDebtLimRise", 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.4518095055541267`*^9, 3.451809511016419*^9}, 
   3.45180973261374*^9, {3.451810063607725*^9, 3.451810068726475*^9}, 
   3.451877640319673*^9}],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxdy39MzHEcx/GvW9HJTq7rB0uoK/0kUSqp192Vfqj7Sdmy9UPH+bFSw5Af
t2lZ64c4lGPCzmxCKC609cOPSqrNhtTIb4mWdENbDOvz/kPf7bPvHp/n5zUv
I1ut5XEcJ/97/v3Hv6+RNyWaB8UL7cEu8L9tJthugkUT7IwDQSF+NWUCZhds
mZMzqFNMYZ6LV961R/hHOWY3nBdWCGTVlshxi2FRiH70Jr5h9oRdefqGwD5z
w7i9YApp8edVfGD2QZpHbFmewsLsh4K2HmP00THmBfD0TtJZhLzGcQdg+7qS
5vaD1syL8OGZyzvHKzbMgRC6+Jmci2yZF6Pe2Dm9313AvAR9rbKL5gg75iAY
eOXzguQzmIPRbwqTXZcKmZfCc3DgaYqrPXMIpuw/VhH1lhyKcoEkLtMgYg6D
kyvv9fEAB+ZlOKbpHD5ZTw7H/FJzjGOoI/NyuI9M6iq6QI5A6ajwnpbvxBwJ
keSJ33AqGTiXJy1PvcSsBzb5n3JoHaIuQa2oMsvL15l1CSxVtTvWpzJzUgyk
NRaoSqhLMbdvr7XpBnUZTh9PGLV6Tl2GiI+FJ/g/qUdhzgthd7D9TNajcObJ
1Bc8X2YuGiLj7q1PI6lHo2nbVblATX0FRnJytWPp1FegO2LaaH829RhsfMu/
Zr+HegxCnWxLaguox8I6qaR57BD1WMS/7Ml3qqAeB942fZ1PJfU4uN1vNSSf
px6P27da/O9cpB6PuoB9v7Kqqa+Ex2pDfGEN9ZVI7xIcnm2mnoAUi+55+G3q
CUgr8p/8vZ56IqwCVjknNVBPRFtd8mZdE3U5fGb9+hR8l7ocO3PPhT+8R10B
a0P3sPcD6grUnLWcXdtCXYmT2iUCXSszlIjd/XuZqo3eK5E/Yi52ecjcqIS+
1/i4g8yp8CPhS4aunfYqKCvfewyR9SosFhhNmY9or0JvykyHdjKnxiDfRivu
oL0apx+9lOaS9WpsMo953CQ3qjEUen31MJnTYI10/ZC4k/YaVF3+9llF1muQ
nK8S7/rrP6MdX0I=
     "]]}, 
   {Dashing[{0.01}], 
    LineBox[{{1, -8.053564549606712}, {78, -8.053564549606712}}]}, 
   InsetBox["\<\"\[UpArrow]\"\>", 
    NCache[{Rational[79, 2], -5.753564549606712}, {
     39.5, -5.753564549606712}], {0, 1}], 
   InsetBox["\<\"\\!\\(\\*OverscriptBox[\\(\[ScriptM]\\), \\(_\\)]\\)-d\"\>", 
    NCache[{Rational[79, 2], -6.053564549606712}, {
     39.5, -6.053564549606712}], {0, 1}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"\[ScriptM]\"", TraditionalForm]},
  AxesOrigin->{-3, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{-3, 75}, {-9.999999999999993, 5.796435450393281}},
  PlotRangeClipping->True,
  Ticks->{{{4, 
      FormBox["\"0\"", TraditionalForm]}}, None}]], "Output",
 CellChangeTimes->{
  3.413723863325436*^9, 3.413723997326157*^9, 3.413728964413769*^9, 
   3.414626829557487*^9, 3.423299948891789*^9, 3.423300949928588*^9, 
   3.4233014747561398`*^9, 3.445685831047063*^9, 3.447956902270228*^9, 
   3.447956983851589*^9, {3.447957032006645*^9, 3.447957059207399*^9}, {
   3.44795710782659*^9, 3.447957125573616*^9}, 3.451809280549582*^9, 
   3.451809513828656*^9, 3.451809733919032*^9, 3.451810170491444*^9, {
   3.45187762920879*^9, 3.451877642841442*^9}, 3.4518780445627937`*^9, 
   3.451914388741126*^9, 3.451921423563204*^9, 3.451930145964055*^9, 
   3.452107809751608*^9, 3.4521084184562607`*^9, 3.452167659704925*^9, 
   3.452201338499537*^9, 3.4522014710003347`*^9, 3.452247743560883*^9, 
   3.45284972598947*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<MPCPathAfterDebtLimRise\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", "MPCPathAfterDebtLimRise"}], "Input",
 CellChangeTimes->{{3.4518095251851473`*^9, 3.451809572238872*^9}, {
  3.451809711360167*^9, 3.451809717372607*^9}, {3.4518100772046022`*^9, 
  3.45181008669156*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxd0H9MzHEcx/FvV5EMp2Q0a4fWKnU7ojjlXrp+XD/U9+6wa/kR82OjzY8Y
M+bTTfPjD243pfnVMfyDdptUUt1XDeXHHEJoNFG5rh9kjBKZz9umz/bdZ4/v
c69/PtPXbjGslwmCkDH8/bn/nj7No9Dq+6LaoeE/8L99Rlg+wpMg6B1PQ0zX
uadAOBOZGlhOngbpTnCRbGo5twI4JxvdwcgzIFRefCh1k4PBBgI27F5dwR0C
afvMUW3PyKEQtJ6zJbGSOxwIar5c8YgcAZw97m0y3OBWgs2/9DGgmawCM/QW
pOdUcc8G8jVhGhd5DqTTTDtt503uKAj1h+96CNXcc8E+zHwhO0KeB6izdyn9
arijAedRd9EJcgyYU6XNmlrLPR/MfGTfhSLyAqBpbJtjPL2nGpLvVw95Pnkh
mDxocmA3ORa2peeb48Mk7jgo7EnLj5rIiyBtim5Yd4CsQas1atW9K2SANbiN
zsfcDLDU6x5Y+6kvhpDXYo32u8X7YshDYzrbI7mFeMCRvONpEvV4qGo98pQr
qWshVfoGz9pGXQtb917zoJl6AmyHX8Y3WaknwD7xvvydjXoixJAhb+NV6olQ
FTfp9ZXUk9BniPXxqqOeBEX9Qfmxe9STYe9RRvg/oZ4McVXmhNJm6jqIpy4V
7HlDXQeFrrTE0kY9Bfah3PfendRTINVmF3R3UU+Fwr3Zauqlngrh8e2I5Z+p
p0G06ir6v1BPg00W4RX3jXo6cqo37o/9Tj0drVvKlw38oL4ETreyOH+Q+hJs
zT604vlP6hlgncpXv4aoZ0ByZB3wFOp4z4RgzpreTmaZsLSY3l72oC7Cntu4
wSTjhgjLUJmrh8xEsE1hMds9uSUROeZPNe/Jgh59+Y3ndF6018M2Ri2VkJke
FhequsiSHs5C10CkN+0NaO0aqNtIhgG2qMbgk2RmAHyM/nfIkgGqMsca97+9
EZbYxIZxo2hvxNY9hR3hZGaEcO11WsKwfwMSzmU+
     "]]}, 
   {Dashing[{0.01}], 
    LineBox[{{1, 0.06052539518198252}, {78, 0.06052539518198252}}]}, 
   InsetBox["\<\"\[UpArrow]\"\>", 
    NCache[{Rational[79, 2], 0.06052539518198252}, {39.5, 
     0.06052539518198252}], {0, 1}], 
   InsetBox["\<\"Perfect Foresight MPC\"\>", 
    NCache[{Rational[79, 2], 0.04842031614558602}, {39.5, 
     0.04842031614558602}], {0, 1}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"\[Kappa](\[ScriptM])\"", TraditionalForm]},
  AxesOrigin->{-3, 0},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{-3, 75}, {0, 0.15}},
  PlotRangeClipping->True,
  Ticks->{{{4, 
      FormBox["\"0\"", TraditionalForm]}}, None}]], "Output",
 CellChangeTimes->{
  3.423301052350875*^9, 3.423301476001053*^9, 3.4456858331616087`*^9, 
   3.447956908097269*^9, 3.4518092842707167`*^9, {3.451809529491376*^9, 
   3.451809575488894*^9}, 3.451809718297079*^9, 3.451810174142172*^9, 
   3.4518776467324553`*^9, 3.451878046582135*^9, 3.451914390369825*^9, 
   3.451921424818326*^9, 3.451930147406658*^9, 3.45210781147379*^9, 
   3.4521084212578583`*^9, 3.452167660964046*^9, 3.452201340736734*^9, 
   3.452201472435637*^9, 3.452247744517589*^9, 3.452849727130433*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"savRat", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", "r", ")"}], "/", "R"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "1"}], "]"}], "]"}], "-", 
          RowBox[{"Table", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", 
             RowBox[{"Length", "[", "\[ScriptM]\[ScriptC]Path", "]"}], 
             "}"}]}], "]"}]}], ")"}]}], "-", 
       RowBox[{"\[ScriptM]\[ScriptC]Path", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savRat", ",", 
    RowBox[{"savRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savRat", ",", 
    RowBox[{"savRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savRat", ",", 
    RowBox[{"savRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"savRat", ",", 
    RowBox[{"savRat", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timePath", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "savRat", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"savPathPlot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"timePath", ",", "savRat"}], "}"}], "]"}], ",", "50"}], 
      "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Black"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"savPathAfterLiqConstrRelax", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"savPathPlot", ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"5", ",", "\"\<t\>\""}], "}"}], "}"}], ",", "None"}], 
      "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", "\"\<\[ScriptS]\>\""}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{
        RowBox[{"Min", "[", "savRat", "]"}], "-", "0.02"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "50"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Min", "[", "savRat", "]"}], "-", "0.02"}], ",", 
         RowBox[{
          RowBox[{"Max", "[", "savRat", "]"}], "+", "0.01`"}]}], "}"}]}], 
      "}"}]}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.452111942712772*^9, 3.4521119437344007`*^9}, {
   3.4521119838671618`*^9, 3.452111998590267*^9}, {3.4521120359108477`*^9, 
   3.4521120450428457`*^9}, {3.4521121072352962`*^9, 3.452112146683333*^9}, {
   3.452201357866541*^9, 3.452201408807786*^9}, 3.452247689961746*^9}],

Cell[BoxData[
 GraphicsBox[
  {GrayLevel[0], PointSize[Medium], PointBox[CompressedData["
1:eJxdyUFI0wEUx/G/YjDQcMaQwh00RowYay1b21rut6n7qzkwY0UlFq6sQ6U2
3AZJjF2k7GAy0ECXjFUGBnboMMKtVdZcc5nMJUPGbCRLDSeZRWRU7HloDx6P
z/uWtbQ1XshlGEb6d//dzKTVpXP36/imUTU98L85WeZmmZflnXCyq3zH7xVf
xny02CctDewyuRSNZ4IigfszeTdkkqWNbl6KLEDx2RwtM7BI3oO0xpIuEX8i
C+HaZL9eiybJe3E3FH3i7v1IFuFY20PNiaYFshjOfU87JIoEWYKrAovxmT5O
3o9Ff+dEYd08WYrgwnndaGuMfABOTrhp1jVHLof98ZcZ/2aUfBAb5+Sd/eZZ
sgzrDzw9lwoi5EMYUTjqpd4ZshwNU5GL87fekxWQ9f7wKDqmyUqM5YiVvESY
fBgq0RXzz/wpsgpd2uvGy8a35CNwL+bduZecJFcgMGBI+28GyGp08Qzfc4+/
IQODel7zoOp1xjZgpai+KFY5QV0Drt1TWNb6iroG/KOntn0bfkldi/L+6b5f
ay+oa+G23tDlnSQzlQgorM1M2E+9Epxlv3m7gcxUAfy4vn3pOfUqyE3FIcdt
MlMN4aOItUC51auR8q7n70r6qOsgPO0SfjCSbTq077ANVax7qbNIhOIpUx/Z
xmK4e2jynWqr18Da3WOJrY1TrwE3OMJlx8hMLSShktpV87jvD6CK+XU=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"\[ScriptS]\"", TraditionalForm]},
  AxesOrigin->{-3, -0.9260764851694676},
  BaseStyle->{FontSize -> 14},
  ImageSize->{468., 289.23990673495075`},
  PlotRange->{{-3, 50}, {-0.9260764851694676, 0.06556572352627164}},
  PlotRangeClipping->True,
  Ticks->{{{5, 
      FormBox["\"t\"", TraditionalForm]}}, None}]], "Output",
 CellChangeTimes->{{3.452112112378614*^9, 3.452112147067707*^9}, 
   3.452167661748518*^9, {3.452201362468704*^9, 3.452201409560425*^9}, 
   3.4522014727433777`*^9, 3.4522477450028553`*^9, 3.452849727463954*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExportFigsToDir", "[", 
   RowBox[{"\"\<savPathAfterLiqConstrRelax\>\"", ",", 
    RowBox[{"NBDir", "<>", "\"\</Figures\>\""}]}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.452112049631226*^9}]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1462, 1006},
WindowMargins->{{105, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 779, 17, 110, "Input"],
Cell[CellGroupData[{
Cell[1361, 41, 3325, 85, 340, "Input",
 InitializationCell->True],
Cell[4689, 128, 445, 10, 56, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5171, 143, 2999, 76, 271, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[8195, 223, 1571, 22, 30, "Print"],
Cell[9769, 247, 1872, 30, 30, "Print"],
Cell[11644, 279, 2016, 34, 30, "Print"],
Cell[13663, 315, 1569, 22, 30, "Print"],
Cell[15235, 339, 1874, 30, 30, "Print"],
Cell[17112, 371, 2025, 34, 39, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19186, 411, 7831, 186, 519, "Input",
 InitializationCell->True],
Cell[27020, 599, 7093, 127, 456, "Output"]
}, Open  ]],
Cell[34128, 729, 260, 6, 40, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[34413, 739, 6989, 183, 404, "Input",
 InitializationCell->True],
Cell[41405, 924, 7988, 144, 456, "Output"]
}, Open  ]],
Cell[49408, 1071, 366, 8, 40, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[49799, 1083, 3630, 102, 225, "Input",
 InitializationCell->True],
Cell[53432, 1187, 1974, 38, 456, "Output"]
}, Open  ]],
Cell[55421, 1228, 308, 7, 40, "Input",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[55754, 1239, 5232, 130, 616, "Input",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[61011, 1373, 1307, 18, 30, "Print"],
Cell[62321, 1393, 1612, 26, 30, "Print"],
Cell[63936, 1421, 1755, 30, 30, "Print"],
Cell[65694, 1453, 1305, 18, 30, "Print"],
Cell[67002, 1473, 1610, 26, 30, "Print"],
Cell[68615, 1501, 1755, 30, 39, "Print"],
Cell[70373, 1533, 1305, 18, 30, "Print"],
Cell[71681, 1553, 1608, 26, 30, "Print"],
Cell[73292, 1581, 1752, 30, 30, "Print"],
Cell[75047, 1613, 1305, 18, 30, "Print"],
Cell[76355, 1633, 1610, 26, 30, "Print"],
Cell[77968, 1661, 1760, 30, 39, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[79777, 1697, 3948, 101, 290, "Input",
 InitializationCell->True],
Cell[83728, 1800, 9707, 168, 456, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93472, 1973, 126, 3, 40, "Input"],
Cell[93601, 1978, 626, 12, 64, "Output"]
}, Open  ]],
Cell[94242, 1993, 389, 8, 40, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[94656, 2005, 3920, 104, 248, "Input",
 InitializationCell->True],
Cell[98579, 2111, 1922, 36, 456, "Output"]
}, Open  ]],
Cell[100516, 2150, 402, 9, 40, "Input",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[100943, 2163, 110, 1, 40, "Input"],
Cell[101056, 2166, 740, 14, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101833, 2185, 192, 4, 40, "Input"],
Cell[102028, 2191, 626, 12, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102691, 2208, 3045, 78, 179, "Input",
 InitializationCell->True],
Cell[105739, 2288, 4583, 82, 456, 885, 21, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[110337, 2373, 447, 9, 40, "Input",
 InitializationGroup->True],
Cell[110787, 2384, 6265, 160, 456, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[117077, 2548, 518, 10, 64, "Input",
 InitializationCell->True],
Cell[117598, 2560, 10097, 175, 456, "Output"]
}, Open  ]],
Cell[127710, 2738, 3616, 101, 485, "Input",
 InitializationCell->True],
Cell[131329, 2841, 7512, 206, 560, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[138866, 3051, 487, 11, 87, "Input",
 InitializationCell->True],
Cell[139356, 3064, 5125, 92, 456, 1584, 33, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144518, 3161, 457, 10, 87, "Input"],
Cell[144978, 3173, 2746, 53, 456, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147761, 3231, 407, 8, 64, "Input"],
Cell[148171, 3241, 2424, 48, 456, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150632, 3294, 3637, 105, 225, "Input",
 InitializationCell->True],
Cell[154272, 3401, 5258, 93, 456, 1299, 27, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[159545, 3497, 257, 6, 40, "Input",
 InitializationCell->True]
}
]
*)

(* End of internal cache information *)
